/* Hashtags.c generated by valac 0.56.19, the Vala compiler
 * generated from Hashtags.vala, do not modify */

#include <adwaita.h>
#include <glib-object.h>
#include <glib.h>
#include <stdlib.h>
#include <string.h>
#include <gtk/gtk.h>
#include <gio/gio.h>
#include <gee.h>
#include <json-glib/json-glib.h>
#include <glib/gi18n-lib.h>

#define TUBA_VIEWS_SIDEBAR_MAX_SIDEBAR_TAGS 25
#if !defined(VALA_STRICT_C)
#if !defined(__clang__) && defined(__GNUC__) && (__GNUC__ >= 14)
#pragma GCC diagnostic warning "-Wincompatible-pointer-types"
#elif defined(__clang__) && (__clang_major__ >= 16)
#pragma clang diagnostic ignored "-Wincompatible-function-pointer-types"
#pragma clang diagnostic ignored "-Wincompatible-pointer-types"
#endif
#endif
#if !defined(VALA_EXTERN)
#if defined(_MSC_VER)
#define VALA_EXTERN __declspec(dllexport) extern
#elif __GNUC__ >= 4
#define VALA_EXTERN __attribute__((visibility("default"))) extern
#else
#define VALA_EXTERN extern
#endif
#endif

#define TUBA_VIEWS_TYPE_BASE (tuba_views_base_get_type ())
#define TUBA_VIEWS_BASE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_VIEWS_TYPE_BASE, TubaViewsBase))
#define TUBA_VIEWS_BASE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUBA_VIEWS_TYPE_BASE, TubaViewsBaseClass))
#define TUBA_VIEWS_IS_BASE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_VIEWS_TYPE_BASE))
#define TUBA_VIEWS_IS_BASE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUBA_VIEWS_TYPE_BASE))
#define TUBA_VIEWS_BASE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUBA_VIEWS_TYPE_BASE, TubaViewsBaseClass))

typedef struct _TubaViewsBase TubaViewsBase;
typedef struct _TubaViewsBaseClass TubaViewsBaseClass;
typedef struct _TubaViewsBasePrivate TubaViewsBasePrivate;

#define TUBA_VIEWS_TYPE_CONTENT_BASE (tuba_views_content_base_get_type ())
#define TUBA_VIEWS_CONTENT_BASE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_VIEWS_TYPE_CONTENT_BASE, TubaViewsContentBase))
#define TUBA_VIEWS_CONTENT_BASE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUBA_VIEWS_TYPE_CONTENT_BASE, TubaViewsContentBaseClass))
#define TUBA_VIEWS_IS_CONTENT_BASE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_VIEWS_TYPE_CONTENT_BASE))
#define TUBA_VIEWS_IS_CONTENT_BASE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUBA_VIEWS_TYPE_CONTENT_BASE))
#define TUBA_VIEWS_CONTENT_BASE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUBA_VIEWS_TYPE_CONTENT_BASE, TubaViewsContentBaseClass))

typedef struct _TubaViewsContentBase TubaViewsContentBase;
typedef struct _TubaViewsContentBaseClass TubaViewsContentBaseClass;
typedef struct _TubaViewsContentBasePrivate TubaViewsContentBasePrivate;

#define TUBA_TYPE_ACCOUNT_HOLDER (tuba_account_holder_get_type ())
#define TUBA_ACCOUNT_HOLDER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_TYPE_ACCOUNT_HOLDER, TubaAccountHolder))
#define TUBA_IS_ACCOUNT_HOLDER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_TYPE_ACCOUNT_HOLDER))
#define TUBA_ACCOUNT_HOLDER_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), TUBA_TYPE_ACCOUNT_HOLDER, TubaAccountHolderIface))

typedef struct _TubaAccountHolder TubaAccountHolder;
typedef struct _TubaAccountHolderIface TubaAccountHolderIface;

#define TUBA_TYPE_ENTITY (tuba_entity_get_type ())
#define TUBA_ENTITY(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_TYPE_ENTITY, TubaEntity))
#define TUBA_ENTITY_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUBA_TYPE_ENTITY, TubaEntityClass))
#define TUBA_IS_ENTITY(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_TYPE_ENTITY))
#define TUBA_IS_ENTITY_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUBA_TYPE_ENTITY))
#define TUBA_ENTITY_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUBA_TYPE_ENTITY, TubaEntityClass))

typedef struct _TubaEntity TubaEntity;
typedef struct _TubaEntityClass TubaEntityClass;

#define TUBA_API_TYPE_ACCOUNT (tuba_api_account_get_type ())
#define TUBA_API_ACCOUNT(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_API_TYPE_ACCOUNT, TubaAPIAccount))
#define TUBA_API_ACCOUNT_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUBA_API_TYPE_ACCOUNT, TubaAPIAccountClass))
#define TUBA_API_IS_ACCOUNT(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_API_TYPE_ACCOUNT))
#define TUBA_API_IS_ACCOUNT_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUBA_API_TYPE_ACCOUNT))
#define TUBA_API_ACCOUNT_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUBA_API_TYPE_ACCOUNT, TubaAPIAccountClass))

typedef struct _TubaAPIAccount TubaAPIAccount;
typedef struct _TubaAPIAccountClass TubaAPIAccountClass;

#define TUBA_TYPE_INSTANCE_ACCOUNT (tuba_instance_account_get_type ())
#define TUBA_INSTANCE_ACCOUNT(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_TYPE_INSTANCE_ACCOUNT, TubaInstanceAccount))
#define TUBA_INSTANCE_ACCOUNT_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUBA_TYPE_INSTANCE_ACCOUNT, TubaInstanceAccountClass))
#define TUBA_IS_INSTANCE_ACCOUNT(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_TYPE_INSTANCE_ACCOUNT))
#define TUBA_IS_INSTANCE_ACCOUNT_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUBA_TYPE_INSTANCE_ACCOUNT))
#define TUBA_INSTANCE_ACCOUNT_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUBA_TYPE_INSTANCE_ACCOUNT, TubaInstanceAccountClass))

typedef struct _TubaInstanceAccount TubaInstanceAccount;
typedef struct _TubaInstanceAccountClass TubaInstanceAccountClass;

#define TUBA_TYPE_STREAMABLE (tuba_streamable_get_type ())
#define TUBA_STREAMABLE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_TYPE_STREAMABLE, TubaStreamable))
#define TUBA_IS_STREAMABLE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_TYPE_STREAMABLE))
#define TUBA_STREAMABLE_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), TUBA_TYPE_STREAMABLE, TubaStreamableIface))

typedef struct _TubaStreamable TubaStreamable;
typedef struct _TubaStreamableIface TubaStreamableIface;

#define TUBA_VIEWS_TYPE_TIMELINE (tuba_views_timeline_get_type ())
#define TUBA_VIEWS_TIMELINE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_VIEWS_TYPE_TIMELINE, TubaViewsTimeline))
#define TUBA_VIEWS_TIMELINE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUBA_VIEWS_TYPE_TIMELINE, TubaViewsTimelineClass))
#define TUBA_VIEWS_IS_TIMELINE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_VIEWS_TYPE_TIMELINE))
#define TUBA_VIEWS_IS_TIMELINE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUBA_VIEWS_TYPE_TIMELINE))
#define TUBA_VIEWS_TIMELINE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUBA_VIEWS_TYPE_TIMELINE, TubaViewsTimelineClass))

typedef struct _TubaViewsTimeline TubaViewsTimeline;
typedef struct _TubaViewsTimelineClass TubaViewsTimelineClass;
typedef struct _TubaViewsTimelinePrivate TubaViewsTimelinePrivate;

#define TUBA_TYPE_REQUEST_V2 (tuba_request_v2_get_type ())
#define TUBA_REQUEST_V2(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_TYPE_REQUEST_V2, TubaRequestV2))
#define TUBA_REQUEST_V2_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUBA_TYPE_REQUEST_V2, TubaRequestV2Class))
#define TUBA_IS_REQUEST_V2(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_TYPE_REQUEST_V2))
#define TUBA_IS_REQUEST_V2_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUBA_TYPE_REQUEST_V2))
#define TUBA_REQUEST_V2_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUBA_TYPE_REQUEST_V2, TubaRequestV2Class))

typedef struct _TubaRequestV2 TubaRequestV2;
typedef struct _TubaRequestV2Class TubaRequestV2Class;

#define TUBA_STREAMABLE_TYPE_EVENT (tuba_streamable_event_get_type ())
typedef struct _TubaStreamableEvent TubaStreamableEvent;

#define TUBA_VIEWS_TYPE_HASHTAGS (tuba_views_hashtags_get_type ())
#define TUBA_VIEWS_HASHTAGS(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_VIEWS_TYPE_HASHTAGS, TubaViewsHashtags))
#define TUBA_VIEWS_HASHTAGS_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUBA_VIEWS_TYPE_HASHTAGS, TubaViewsHashtagsClass))
#define TUBA_VIEWS_IS_HASHTAGS(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_VIEWS_TYPE_HASHTAGS))
#define TUBA_VIEWS_IS_HASHTAGS_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUBA_VIEWS_TYPE_HASHTAGS))
#define TUBA_VIEWS_HASHTAGS_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUBA_VIEWS_TYPE_HASHTAGS, TubaViewsHashtagsClass))

typedef struct _TubaViewsHashtags TubaViewsHashtags;
typedef struct _TubaViewsHashtagsClass TubaViewsHashtagsClass;
typedef struct _TubaViewsHashtagsPrivate TubaViewsHashtagsPrivate;
enum  {
	TUBA_VIEWS_HASHTAGS_0_PROPERTY,
	TUBA_VIEWS_HASHTAGS_NUM_PROPERTIES
};
static GParamSpec* tuba_views_hashtags_properties[TUBA_VIEWS_HASHTAGS_NUM_PROPERTIES];

#define TUBA_API_TYPE_TAG (tuba_api_tag_get_type ())
#define TUBA_API_TAG(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_API_TYPE_TAG, TubaAPITag))
#define TUBA_API_TAG_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUBA_API_TYPE_TAG, TubaAPITagClass))
#define TUBA_API_IS_TAG(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_API_TYPE_TAG))
#define TUBA_API_IS_TAG_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUBA_API_TYPE_TAG))
#define TUBA_API_TAG_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUBA_API_TYPE_TAG, TubaAPITagClass))

typedef struct _TubaAPITag TubaAPITag;
typedef struct _TubaAPITagClass TubaAPITagClass;

#define TUBA_VIEWS_HASHTAGS_TYPE_FAVORITE_TAG (tuba_views_hashtags_favorite_tag_get_type ())
#define TUBA_VIEWS_HASHTAGS_FAVORITE_TAG(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_VIEWS_HASHTAGS_TYPE_FAVORITE_TAG, TubaViewsHashtagsFavoriteTag))
#define TUBA_VIEWS_HASHTAGS_FAVORITE_TAG_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUBA_VIEWS_HASHTAGS_TYPE_FAVORITE_TAG, TubaViewsHashtagsFavoriteTagClass))
#define TUBA_VIEWS_HASHTAGS_IS_FAVORITE_TAG(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_VIEWS_HASHTAGS_TYPE_FAVORITE_TAG))
#define TUBA_VIEWS_HASHTAGS_IS_FAVORITE_TAG_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUBA_VIEWS_HASHTAGS_TYPE_FAVORITE_TAG))
#define TUBA_VIEWS_HASHTAGS_FAVORITE_TAG_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUBA_VIEWS_HASHTAGS_TYPE_FAVORITE_TAG, TubaViewsHashtagsFavoriteTagClass))

typedef struct _TubaViewsHashtagsFavoriteTag TubaViewsHashtagsFavoriteTag;
typedef struct _TubaViewsHashtagsFavoriteTagClass TubaViewsHashtagsFavoriteTagClass;

#define TUBA_DIALOGS_HASHTAG_LIST_TYPE_DATA (tuba_dialogs_hashtag_list_data_get_type ())
#define TUBA_DIALOGS_HASHTAG_LIST_DATA(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_DIALOGS_HASHTAG_LIST_TYPE_DATA, TubaDialogsHashtagListData))
#define TUBA_DIALOGS_HASHTAG_LIST_DATA_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUBA_DIALOGS_HASHTAG_LIST_TYPE_DATA, TubaDialogsHashtagListDataClass))
#define TUBA_DIALOGS_HASHTAG_LIST_IS_DATA(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_DIALOGS_HASHTAG_LIST_TYPE_DATA))
#define TUBA_DIALOGS_HASHTAG_LIST_IS_DATA_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUBA_DIALOGS_HASHTAG_LIST_TYPE_DATA))
#define TUBA_DIALOGS_HASHTAG_LIST_DATA_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUBA_DIALOGS_HASHTAG_LIST_TYPE_DATA, TubaDialogsHashtagListDataClass))

typedef struct _TubaDialogsHashtagListData TubaDialogsHashtagListData;
typedef struct _TubaDialogsHashtagListDataClass TubaDialogsHashtagListDataClass;
#define _g_free0(var) (var = (g_free (var), NULL))
#define _g_object_unref0(var) ((var == NULL) ? NULL : (var = (g_object_unref (var), NULL)))

#define TUBA_DIALOGS_TYPE_HASHTAG_LIST (tuba_dialogs_hashtag_list_get_type ())
#define TUBA_DIALOGS_HASHTAG_LIST(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_DIALOGS_TYPE_HASHTAG_LIST, TubaDialogsHashtagList))
#define TUBA_DIALOGS_HASHTAG_LIST_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUBA_DIALOGS_TYPE_HASHTAG_LIST, TubaDialogsHashtagListClass))
#define TUBA_DIALOGS_IS_HASHTAG_LIST(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_DIALOGS_TYPE_HASHTAG_LIST))
#define TUBA_DIALOGS_IS_HASHTAG_LIST_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUBA_DIALOGS_TYPE_HASHTAG_LIST))
#define TUBA_DIALOGS_HASHTAG_LIST_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUBA_DIALOGS_TYPE_HASHTAG_LIST, TubaDialogsHashtagListClass))

typedef struct _TubaDialogsHashtagList TubaDialogsHashtagList;
typedef struct _TubaDialogsHashtagListClass TubaDialogsHashtagListClass;

#define TUBA_TYPE_APPLICATION (tuba_application_get_type ())
#define TUBA_APPLICATION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_TYPE_APPLICATION, TubaApplication))
#define TUBA_APPLICATION_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUBA_TYPE_APPLICATION, TubaApplicationClass))
#define TUBA_IS_APPLICATION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_TYPE_APPLICATION))
#define TUBA_IS_APPLICATION_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUBA_TYPE_APPLICATION))
#define TUBA_APPLICATION_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUBA_TYPE_APPLICATION, TubaApplicationClass))

typedef struct _TubaApplication TubaApplication;
typedef struct _TubaApplicationClass TubaApplicationClass;

#define TUBA_DIALOGS_TYPE_MAIN_WINDOW (tuba_dialogs_main_window_get_type ())
#define TUBA_DIALOGS_MAIN_WINDOW(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_DIALOGS_TYPE_MAIN_WINDOW, TubaDialogsMainWindow))
#define TUBA_DIALOGS_MAIN_WINDOW_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUBA_DIALOGS_TYPE_MAIN_WINDOW, TubaDialogsMainWindowClass))
#define TUBA_DIALOGS_IS_MAIN_WINDOW(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_DIALOGS_TYPE_MAIN_WINDOW))
#define TUBA_DIALOGS_IS_MAIN_WINDOW_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUBA_DIALOGS_TYPE_MAIN_WINDOW))
#define TUBA_DIALOGS_MAIN_WINDOW_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUBA_DIALOGS_TYPE_MAIN_WINDOW, TubaDialogsMainWindowClass))

typedef struct _TubaDialogsMainWindow TubaDialogsMainWindow;
typedef struct _TubaDialogsMainWindowClass TubaDialogsMainWindowClass;

#define TUBA_TYPE_SETTINGS (tuba_settings_get_type ())
#define TUBA_SETTINGS(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_TYPE_SETTINGS, TubaSettings))
#define TUBA_SETTINGS_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUBA_TYPE_SETTINGS, TubaSettingsClass))
#define TUBA_IS_SETTINGS(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_TYPE_SETTINGS))
#define TUBA_IS_SETTINGS_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUBA_TYPE_SETTINGS))
#define TUBA_SETTINGS_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUBA_TYPE_SETTINGS, TubaSettingsClass))

typedef struct _TubaSettings TubaSettings;
typedef struct _TubaSettingsClass TubaSettingsClass;

#define TUBA_TYPE_ACCOUNT_STORE (tuba_account_store_get_type ())
#define TUBA_ACCOUNT_STORE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_TYPE_ACCOUNT_STORE, TubaAccountStore))
#define TUBA_ACCOUNT_STORE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUBA_TYPE_ACCOUNT_STORE, TubaAccountStoreClass))
#define TUBA_IS_ACCOUNT_STORE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_TYPE_ACCOUNT_STORE))
#define TUBA_IS_ACCOUNT_STORE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUBA_TYPE_ACCOUNT_STORE))
#define TUBA_ACCOUNT_STORE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUBA_TYPE_ACCOUNT_STORE, TubaAccountStoreClass))

typedef struct _TubaAccountStore TubaAccountStore;
typedef struct _TubaAccountStoreClass TubaAccountStoreClass;

#define TUBA_VIEWS_HASHTAGS_TYPE_HASHTAG_LIST (tuba_views_hashtags_hashtag_list_get_type ())
#define TUBA_VIEWS_HASHTAGS_HASHTAG_LIST(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_VIEWS_HASHTAGS_TYPE_HASHTAG_LIST, TubaViewsHashtagsHashtagList))
#define TUBA_VIEWS_HASHTAGS_HASHTAG_LIST_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUBA_VIEWS_HASHTAGS_TYPE_HASHTAG_LIST, TubaViewsHashtagsHashtagListClass))
#define TUBA_VIEWS_HASHTAGS_IS_HASHTAG_LIST(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_VIEWS_HASHTAGS_TYPE_HASHTAG_LIST))
#define TUBA_VIEWS_HASHTAGS_IS_HASHTAG_LIST_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUBA_VIEWS_HASHTAGS_TYPE_HASHTAG_LIST))
#define TUBA_VIEWS_HASHTAGS_HASHTAG_LIST_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUBA_VIEWS_HASHTAGS_TYPE_HASHTAG_LIST, TubaViewsHashtagsHashtagListClass))

typedef struct _TubaViewsHashtagsHashtagList TubaViewsHashtagsHashtagList;
typedef struct _TubaViewsHashtagsHashtagListClass TubaViewsHashtagsHashtagListClass;
typedef struct _TubaViewsHashtagsHashtagListPrivate TubaViewsHashtagsHashtagListPrivate;
enum  {
	TUBA_VIEWS_HASHTAGS_HASHTAG_LIST_0_PROPERTY,
	TUBA_VIEWS_HASHTAGS_HASHTAG_LIST_NUM_PROPERTIES
};
static GParamSpec* tuba_views_hashtags_hashtag_list_properties[TUBA_VIEWS_HASHTAGS_HASHTAG_LIST_NUM_PROPERTIES];

#define TUBA_TYPE_WIDGETIZABLE (tuba_widgetizable_get_type ())
#define TUBA_WIDGETIZABLE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_TYPE_WIDGETIZABLE, TubaWidgetizable))
#define TUBA_IS_WIDGETIZABLE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_TYPE_WIDGETIZABLE))
#define TUBA_WIDGETIZABLE_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), TUBA_TYPE_WIDGETIZABLE, TubaWidgetizableIface))

typedef struct _TubaWidgetizable TubaWidgetizable;
typedef struct _TubaWidgetizableIface TubaWidgetizableIface;
typedef struct _TubaEntityPrivate TubaEntityPrivate;
typedef struct _TubaAPITagPrivate TubaAPITagPrivate;
typedef struct _TubaViewsHashtagsFavoriteTagPrivate TubaViewsHashtagsFavoriteTagPrivate;
enum  {
	TUBA_VIEWS_HASHTAGS_FAVORITE_TAG_0_PROPERTY,
	TUBA_VIEWS_HASHTAGS_FAVORITE_TAG_TUBA_HASHTAG_DATA_PROPERTY,
	TUBA_VIEWS_HASHTAGS_FAVORITE_TAG_NUM_PROPERTIES
};
static GParamSpec* tuba_views_hashtags_favorite_tag_properties[TUBA_VIEWS_HASHTAGS_FAVORITE_TAG_NUM_PROPERTIES];

#define TUBA_WIDGETS_TYPE_STATUS_ACTION_BUTTON (tuba_widgets_status_action_button_get_type ())
#define TUBA_WIDGETS_STATUS_ACTION_BUTTON(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_WIDGETS_TYPE_STATUS_ACTION_BUTTON, TubaWidgetsStatusActionButton))
#define TUBA_WIDGETS_STATUS_ACTION_BUTTON_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUBA_WIDGETS_TYPE_STATUS_ACTION_BUTTON, TubaWidgetsStatusActionButtonClass))
#define TUBA_WIDGETS_IS_STATUS_ACTION_BUTTON(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_WIDGETS_TYPE_STATUS_ACTION_BUTTON))
#define TUBA_WIDGETS_IS_STATUS_ACTION_BUTTON_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUBA_WIDGETS_TYPE_STATUS_ACTION_BUTTON))
#define TUBA_WIDGETS_STATUS_ACTION_BUTTON_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUBA_WIDGETS_TYPE_STATUS_ACTION_BUTTON, TubaWidgetsStatusActionButtonClass))

typedef struct _TubaWidgetsStatusActionButton TubaWidgetsStatusActionButton;
typedef struct _TubaWidgetsStatusActionButtonClass TubaWidgetsStatusActionButtonClass;

#define TUBA_VIEWS_HASHTAGS_FAVORITE_TAG_TYPE_FAVORITE_BUTTON (tuba_views_hashtags_favorite_tag_favorite_button_get_type ())
#define TUBA_VIEWS_HASHTAGS_FAVORITE_TAG_FAVORITE_BUTTON(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_VIEWS_HASHTAGS_FAVORITE_TAG_TYPE_FAVORITE_BUTTON, TubaViewsHashtagsFavoriteTagFavoriteButton))
#define TUBA_VIEWS_HASHTAGS_FAVORITE_TAG_FAVORITE_BUTTON_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUBA_VIEWS_HASHTAGS_FAVORITE_TAG_TYPE_FAVORITE_BUTTON, TubaViewsHashtagsFavoriteTagFavoriteButtonClass))
#define TUBA_VIEWS_HASHTAGS_FAVORITE_TAG_IS_FAVORITE_BUTTON(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_VIEWS_HASHTAGS_FAVORITE_TAG_TYPE_FAVORITE_BUTTON))
#define TUBA_VIEWS_HASHTAGS_FAVORITE_TAG_IS_FAVORITE_BUTTON_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUBA_VIEWS_HASHTAGS_FAVORITE_TAG_TYPE_FAVORITE_BUTTON))
#define TUBA_VIEWS_HASHTAGS_FAVORITE_TAG_FAVORITE_BUTTON_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUBA_VIEWS_HASHTAGS_FAVORITE_TAG_TYPE_FAVORITE_BUTTON, TubaViewsHashtagsFavoriteTagFavoriteButtonClass))

typedef struct _TubaViewsHashtagsFavoriteTagFavoriteButton TubaViewsHashtagsFavoriteTagFavoriteButton;
typedef struct _TubaViewsHashtagsFavoriteTagFavoriteButtonClass TubaViewsHashtagsFavoriteTagFavoriteButtonClass;
typedef struct _TubaWidgetsStatusActionButtonPrivate TubaWidgetsStatusActionButtonPrivate;
typedef struct _TubaViewsHashtagsFavoriteTagFavoriteButtonPrivate TubaViewsHashtagsFavoriteTagFavoriteButtonPrivate;
enum  {
	TUBA_VIEWS_HASHTAGS_FAVORITE_TAG_FAVORITE_BUTTON_0_PROPERTY,
	TUBA_VIEWS_HASHTAGS_FAVORITE_TAG_FAVORITE_BUTTON_NUM_PROPERTIES
};
static GParamSpec* tuba_views_hashtags_favorite_tag_favorite_button_properties[TUBA_VIEWS_HASHTAGS_FAVORITE_TAG_FAVORITE_BUTTON_NUM_PROPERTIES];

struct _TubaViewsBase {
	AdwBreakpointBin parent_instance;
	TubaViewsBasePrivate * priv;
	AdwHeaderBar* header;
	AdwToolbarView* toolbar_view;
	GtkScrolledWindow* scrolled;
	GtkOverlay* scrolled_overlay;
	GtkRevealer* scroll_to_top_rev;
	GtkButton* scroll_to_top;
	GtkStack* states;
	AdwClamp* content_box;
	GtkButton* status_button;
};

struct _TubaViewsBaseClass {
	AdwBreakpointBinClass parent_class;
	void (*scroll_page) (TubaViewsBase* self, gboolean up);
	void (*unbind_listboxes) (TubaViewsBase* self);
	void (*build_actions) (TubaViewsBase* self);
	void (*build_header) (TubaViewsBase* self);
	void (*clear) (TubaViewsBase* self);
	void (*on_shown) (TubaViewsBase* self);
	void (*on_hidden) (TubaViewsBase* self);
	void (*on_content_changed) (TubaViewsBase* self);
	void (*on_error) (TubaViewsBase* self, gint32 code, const gchar* reason);
};

struct _TubaViewsContentBase {
	TubaViewsBase parent_instance;
	TubaViewsContentBasePrivate * priv;
	GtkListBox* content;
	GListStore* model;
};

struct _TubaViewsContentBaseClass {
	TubaViewsBaseClass parent_class;
	void (*on_scrolled_vadjustment_value_change) (TubaViewsContentBase* self);
	void (*clear_all_but_first) (TubaViewsContentBase* self, gint i);
	void (*attempt_focus_grab) (TubaViewsContentBase* self);
	GtkWidget* (*on_create_model_widget) (TubaViewsContentBase* self, GObject* obj);
	void (*on_bottom_reached) (TubaViewsContentBase* self);
	void (*on_content_item_activated) (TubaViewsContentBase* self, GtkListBoxRow* row);
	gboolean (*get_empty) (TubaViewsContentBase* self);
};

struct _TubaAccountHolderIface {
	GTypeInterface parent_iface;
	void (*on_account_changed) (TubaAccountHolder* self, TubaInstanceAccount* acc);
	void (*on_accounts_changed) (TubaAccountHolder* self, GeeArrayList* accounts);
	TubaInstanceAccount* (*get_account) (TubaAccountHolder* self);
	void (*set_account) (TubaAccountHolder* self, TubaInstanceAccount* value);
};

struct _TubaStreamableIface {
	GTypeInterface parent_iface;
	gchar* (*get_stream_url) (TubaStreamable* self);
	void (*on_streaming_policy_changed) (TubaStreamable* self);
	const gchar* (*get_t_connection_url) (TubaStreamable* self);
	void (*set_t_connection_url) (TubaStreamable* self, const gchar* value);
	gboolean (*get_subscribed) (TubaStreamable* self);
	void (*set_subscribed) (TubaStreamable* self, gboolean value);
};

struct _TubaStreamableEvent {
	gchar* type;
	JsonNode* payload;
};

struct _TubaViewsTimeline {
	TubaViewsContentBase parent_instance;
	TubaViewsTimelinePrivate * priv;
};

struct _TubaViewsTimelineClass {
	TubaViewsContentBaseClass parent_class;
	gchar* (*get_req_url) (TubaViewsTimeline* self);
	void (*append_params_v2) (TubaViewsTimeline* self, TubaRequestV2* req);
	void (*on_request_finish) (TubaViewsTimeline* self);
	void (*request) (TubaViewsTimeline* self, GAsyncReadyCallback _callback_, gpointer _user_data_);
	void (*request_finish) (TubaViewsTimeline* self, GAsyncResult* _res_);
	void (*on_refresh) (TubaViewsTimeline* self);
	void (*on_manual_refresh) (TubaViewsTimeline* self);
	void (*on_account_changed) (TubaViewsTimeline* self, TubaInstanceAccount* acc);
	gchar* (*get_stream_url) (TubaViewsTimeline* self);
	gboolean (*should_hide) (TubaViewsTimeline* self, TubaEntity* entity);
	void (*on_new_post) (TubaViewsTimeline* self, TubaStreamableEvent* ev);
	void (*on_edit_post) (TubaViewsTimeline* self, TubaStreamableEvent* ev);
	void (*on_delete_post) (TubaViewsTimeline* self, TubaStreamableEvent* ev);
	void (*on_remove_user) (TubaViewsTimeline* self, const gchar* user_id);
};

struct _TubaViewsHashtags {
	TubaViewsTimeline parent_instance;
	TubaViewsHashtagsPrivate * priv;
};

struct _TubaViewsHashtagsClass {
	TubaViewsTimelineClass parent_class;
};

struct _TubaViewsHashtagsHashtagList {
	TubaViewsTimeline parent_instance;
	TubaViewsHashtagsHashtagListPrivate * priv;
};

struct _TubaViewsHashtagsHashtagListClass {
	TubaViewsTimelineClass parent_class;
};

struct _TubaWidgetizableIface {
	GTypeInterface parent_iface;
	GtkWidget* (*to_widget) (TubaWidgetizable* self);
	void (*open) (TubaWidgetizable* self);
	void (*resolve_open) (TubaWidgetizable* self, TubaInstanceAccount* account);
};

struct _TubaEntity {
	GObject parent_instance;
	TubaEntityPrivate * priv;
};

struct _TubaEntityClass {
	GObjectClass parent_class;
	gboolean (*is_local) (TubaEntity* self, TubaInstanceAccount* account);
	GType (*deserialize_array_type) (TubaEntity* self, const gchar* prop);
};

struct _TubaAPITag {
	TubaEntity parent_instance;
	TubaAPITagPrivate * priv;
};

struct _TubaAPITagClass {
	TubaEntityClass parent_class;
	void (*on_activated) (TubaAPITag* self);
};

struct _TubaViewsHashtagsFavoriteTag {
	TubaAPITag parent_instance;
	TubaViewsHashtagsFavoriteTagPrivate * priv;
};

struct _TubaViewsHashtagsFavoriteTagClass {
	TubaAPITagClass parent_class;
};

struct _TubaViewsHashtagsFavoriteTagPrivate {
	TubaDialogsHashtagListData* _tuba_hashtag_data;
};

struct _TubaWidgetsStatusActionButton {
	GtkButton parent_instance;
	TubaWidgetsStatusActionButtonPrivate * priv;
};

struct _TubaWidgetsStatusActionButtonClass {
	GtkButtonClass parent_class;
};

struct _TubaViewsHashtagsFavoriteTagFavoriteButton {
	TubaWidgetsStatusActionButton parent_instance;
	TubaViewsHashtagsFavoriteTagFavoriteButtonPrivate * priv;
};

struct _TubaViewsHashtagsFavoriteTagFavoriteButtonClass {
	TubaWidgetsStatusActionButtonClass parent_class;
};

struct _TubaViewsHashtagsFavoriteTagFavoriteButtonPrivate {
	gchar* _tag;
	gboolean _force_recheck;
};

static gpointer tuba_views_hashtags_parent_class = NULL;
VALA_EXTERN TubaApplication* tuba_app;
VALA_EXTERN TubaSettings* tuba_settings;
VALA_EXTERN TubaAccountStore* tuba_accounts;
static gpointer tuba_views_hashtags_hashtag_list_parent_class = NULL;
static gint TubaViewsHashtagsFavoriteTag_private_offset;
static gpointer tuba_views_hashtags_favorite_tag_parent_class = NULL;
static gint TubaViewsHashtagsFavoriteTagFavoriteButton_private_offset;
static gpointer tuba_views_hashtags_favorite_tag_favorite_button_parent_class = NULL;
static TubaWidgetizableIface * tuba_views_hashtags_favorite_tag_tuba_widgetizable_parent_iface = NULL;

VALA_EXTERN GType tuba_views_base_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaViewsBase, g_object_unref)
VALA_EXTERN GType tuba_views_content_base_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaViewsContentBase, g_object_unref)
VALA_EXTERN GType tuba_entity_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaEntity, g_object_unref)
VALA_EXTERN GType tuba_api_account_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaAPIAccount, g_object_unref)
VALA_EXTERN GType tuba_instance_account_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaInstanceAccount, g_object_unref)
VALA_EXTERN GType tuba_account_holder_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaAccountHolder, g_object_unref)
VALA_EXTERN GType tuba_streamable_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaStreamable, g_object_unref)
VALA_EXTERN GType tuba_views_timeline_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaViewsTimeline, g_object_unref)
VALA_EXTERN GType tuba_request_v2_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaRequestV2, g_object_unref)
VALA_EXTERN GType tuba_streamable_event_get_type (void) G_GNUC_CONST ;
VALA_EXTERN TubaStreamableEvent* tuba_streamable_event_dup (const TubaStreamableEvent* self);
VALA_EXTERN void tuba_streamable_event_free (TubaStreamableEvent* self);
VALA_EXTERN void tuba_streamable_event_copy (const TubaStreamableEvent* self,
                                 TubaStreamableEvent* dest);
VALA_EXTERN void tuba_streamable_event_destroy (TubaStreamableEvent* self);
G_DEFINE_AUTO_CLEANUP_CLEAR_FUNC (TubaStreamableEvent, tuba_streamable_event_destroy)
VALA_EXTERN GType tuba_views_hashtags_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaViewsHashtags, g_object_unref)
VALA_EXTERN void tuba_views_timeline_on_request_finish (TubaViewsTimeline* self);
VALA_EXTERN void tuba_views_base_build_header (TubaViewsBase* self);
VALA_EXTERN void tuba_views_timeline_on_refresh (TubaViewsTimeline* self);
VALA_EXTERN TubaViewsHashtags* tuba_views_hashtags_new (void);
VALA_EXTERN TubaViewsHashtags* tuba_views_hashtags_construct (GType object_type);
static void tuba_views_hashtags_real_on_request_finish (TubaViewsTimeline* base);
VALA_EXTERN gboolean tuba_views_timeline_get_has_finished_request (TubaViewsTimeline* self);
static gint tuba_views_hashtags_compare_hashtags (GObject* a,
                                           GObject* b);
static gint _tuba_views_hashtags_compare_hashtags_gcompare_data_func (gconstpointer a,
                                                               gconstpointer b,
                                                               gpointer self);
VALA_EXTERN GType tuba_api_tag_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaAPITag, g_object_unref)
VALA_EXTERN GType tuba_views_hashtags_favorite_tag_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaViewsHashtagsFavoriteTag, g_object_unref)
VALA_EXTERN GType tuba_dialogs_hashtag_list_data_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaDialogsHashtagListData, g_object_unref)
VALA_EXTERN TubaDialogsHashtagListData* tuba_views_hashtags_favorite_tag_get_tuba_hashtag_data (TubaViewsHashtagsFavoriteTag* self);
VALA_EXTERN const gchar* tuba_api_tag_get_name (TubaAPITag* self);
static void tuba_views_hashtags_real_build_header (TubaViewsBase* base);
static void tuba_views_hashtags_on_new_list (TubaViewsHashtags* self);
static void _tuba_views_hashtags_on_new_list_gtk_button_clicked (GtkButton* _sender,
                                                          gpointer self);
VALA_EXTERN GType tuba_dialogs_hashtag_list_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaDialogsHashtagList, g_object_unref)
VALA_EXTERN TubaDialogsHashtagList* tuba_dialogs_hashtag_list_new (TubaDialogsHashtagListData* data);
VALA_EXTERN TubaDialogsHashtagList* tuba_dialogs_hashtag_list_construct (GType object_type,
                                                             TubaDialogsHashtagListData* data);
static void tuba_views_hashtags_on_created_list (TubaViewsHashtags* self);
static void _tuba_views_hashtags_on_created_list_tuba_dialogs_hashtag_list_created (TubaDialogsHashtagList* _sender,
                                                                             gpointer self);
VALA_EXTERN GType tuba_application_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaApplication, g_object_unref)
VALA_EXTERN GType tuba_dialogs_main_window_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaDialogsMainWindow, g_object_unref)
VALA_EXTERN TubaDialogsMainWindow* tuba_application_get_main_window (TubaApplication* self);
static void tuba_views_hashtags_real_on_refresh (TubaViewsTimeline* base);
VALA_EXTERN gboolean tuba_views_hashtags_load_hashtag_lists (TubaViewsHashtags* self);
static gboolean _tuba_views_hashtags_load_hashtag_lists_gsource_func (gpointer self);
VALA_EXTERN GType tuba_settings_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaSettings, g_object_unref)
VALA_EXTERN gchar** tuba_settings_get_hashtag_lists (TubaSettings* self,
                                         gint* result_length1);
VALA_EXTERN TubaDialogsHashtagListData* tuba_dialogs_hashtag_list_data_new_from_string (const gchar* data_string);
VALA_EXTERN TubaDialogsHashtagListData* tuba_dialogs_hashtag_list_data_construct_from_string (GType object_type,
                                                                                  const gchar* data_string);
VALA_EXTERN const gchar* tuba_dialogs_hashtag_list_data_get_title (TubaDialogsHashtagListData* self);
VALA_EXTERN TubaViewsHashtagsFavoriteTag* tuba_views_hashtags_favorite_tag_new (void);
VALA_EXTERN TubaViewsHashtagsFavoriteTag* tuba_views_hashtags_favorite_tag_construct (GType object_type);
VALA_EXTERN void tuba_api_tag_set_name (TubaAPITag* self,
                            const gchar* value);
VALA_EXTERN void tuba_views_hashtags_favorite_tag_set_tuba_hashtag_data (TubaViewsHashtagsFavoriteTag* self,
                                                             TubaDialogsHashtagListData* value);
static void _vala_array_add85 (GObject** * array,
                        gint* length,
                        gint* size,
                        GObject* value);
VALA_EXTERN void tuba_views_hashtags_add_tag_to_favs (const gchar* name);
VALA_EXTERN gchar** tuba_settings_get_favorite_tags_ids (TubaSettings* self,
                                             gint* result_length1);
static gboolean _vala_string_array_contains (gchar* * stack,
                                      gssize stack_length,
                                      const gchar* needle);
static void _vala_array_add86 (gchar** * array,
                        gint* length,
                        gint* size,
                        gchar* value);
static void _vala_array_add87 (gchar** * array,
                        gint* length,
                        gint* size,
                        gchar* value);
VALA_EXTERN void tuba_settings_set_favorite_tags_ids (TubaSettings* self,
                                          gchar** value,
                                          gint value_length1);
VALA_EXTERN GType tuba_account_store_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaAccountStore, g_object_unref)
VALA_EXTERN TubaInstanceAccount* tuba_account_store_get_active (TubaAccountStore* self);
VALA_EXTERN gboolean tuba_instance_account_gather_fav_tags (TubaInstanceAccount* self);
static gboolean _tuba_instance_account_gather_fav_tags_gsource_func (gpointer self);
VALA_EXTERN void tuba_views_hashtags_remove_tag_from_favs (const gchar* name);
static void _vala_array_add88 (gchar** * array,
                        gint* length,
                        gint* size,
                        gchar* value);
VALA_EXTERN GType tuba_views_hashtags_hashtag_list_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaViewsHashtagsHashtagList, g_object_unref)
VALA_EXTERN TubaViewsHashtagsHashtagList* tuba_views_hashtags_hashtag_list_new (const gchar* title,
                                                                    const gchar* uri_part);
VALA_EXTERN TubaViewsHashtagsHashtagList* tuba_views_hashtags_hashtag_list_construct (GType object_type,
                                                                          const gchar* title,
                                                                          const gchar* uri_part);
static GType tuba_views_hashtags_hashtag_list_get_type_once (void);
VALA_EXTERN GType tuba_widgetizable_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaWidgetizable, g_object_unref)
VALA_EXTERN void tuba_api_tag_on_activated (TubaAPITag* self);
static GtkWidget* tuba_views_hashtags_favorite_tag_real_to_widget (TubaWidgetizable* base);
VALA_EXTERN GtkWidget* tuba_widgetizable_to_widget (TubaWidgetizable* self);
VALA_EXTERN TubaViewsHashtagsFavoriteTagFavoriteButton* tuba_views_hashtags_favorite_tag_favorite_button_new (const gchar* tag,
                                                                                                  gboolean force_recheck);
VALA_EXTERN TubaViewsHashtagsFavoriteTagFavoriteButton* tuba_views_hashtags_favorite_tag_favorite_button_construct (GType object_type,
                                                                                                        const gchar* tag,
                                                                                                        gboolean force_recheck);
VALA_EXTERN GType tuba_widgets_status_action_button_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaWidgetsStatusActionButton, g_object_unref)
VALA_EXTERN GType tuba_views_hashtags_favorite_tag_favorite_button_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaViewsHashtagsFavoriteTagFavoriteButton, g_object_unref)
VALA_EXTERN gchar* tuba_dialogs_hashtag_list_data_to_sub (TubaDialogsHashtagListData* self);
static void tuba_views_hashtags_favorite_tag_on_edit_hashtag_list (TubaViewsHashtagsFavoriteTag* self);
static void _tuba_views_hashtags_favorite_tag_on_edit_hashtag_list_gtk_button_clicked (GtkButton* _sender,
                                                                                gpointer self);
static void tuba_views_hashtags_favorite_tag_on_remove_hl_clicked (TubaViewsHashtagsFavoriteTag* self);
static void _tuba_views_hashtags_favorite_tag_on_remove_hl_clicked_gtk_button_clicked (GtkButton* _sender,
                                                                                gpointer self);
static void tuba_views_hashtags_favorite_tag_real_on_activated (TubaAPITag* base);
VALA_EXTERN TubaViewsBase* tuba_dialogs_main_window_open_view (TubaDialogsMainWindow* self,
                                                   TubaViewsBase* view);
VALA_EXTERN gchar* tuba_dialogs_hashtag_list_data_to_uri_part (TubaDialogsHashtagListData* self);
static void tuba_views_hashtags_favorite_tag_on_edited_list (TubaViewsHashtagsFavoriteTag* self);
static void _tuba_views_hashtags_favorite_tag_on_edited_list_tuba_dialogs_hashtag_list_created (TubaDialogsHashtagList* _sender,
                                                                                         gpointer self);
VALA_EXTERN void tuba_dialogs_hashtag_list_remove_hashtag_list (const gchar* uuid);
VALA_EXTERN const gchar* tuba_dialogs_hashtag_list_data_get_uuid (TubaDialogsHashtagListData* self);
VALA_EXTERN TubaAPITag* tuba_api_tag_new (void);
VALA_EXTERN TubaAPITag* tuba_api_tag_construct (GType object_type);
static void tuba_views_hashtags_favorite_tag_favorite_button_set_tag (TubaViewsHashtagsFavoriteTagFavoriteButton* self,
                                                               const gchar* value);
static void tuba_views_hashtags_favorite_tag_favorite_button_set_force_recheck (TubaViewsHashtagsFavoriteTagFavoriteButton* self,
                                                                         gboolean value);
VALA_EXTERN void tuba_widgets_status_action_button_set_active_icon_name (TubaWidgetsStatusActionButton* self,
                                                             const gchar* value);
static void tuba_views_hashtags_favorite_tag_favorite_button_on_favorite_button_clicked (TubaViewsHashtagsFavoriteTagFavoriteButton* self);
static void _tuba_views_hashtags_favorite_tag_favorite_button_on_favorite_button_clicked_gtk_button_clicked (GtkButton* _sender,
                                                                                                      gpointer self);
static void tuba_views_hashtags_favorite_tag_favorite_button_on_fav_tags_updated (TubaViewsHashtagsFavoriteTagFavoriteButton* self);
static void _tuba_views_hashtags_favorite_tag_favorite_button_on_fav_tags_updated_g_object_notify (GObject* _sender,
                                                                                            GParamSpec* pspec,
                                                                                            gpointer self);
static void tuba_views_hashtags_favorite_tag_favorite_button_update_fav_status (TubaViewsHashtagsFavoriteTagFavoriteButton* self,
                                                                         const gchar* changed_tag);
static void _tuba_views_hashtags_favorite_tag_favorite_button_update_fav_status_tuba_application_fav_tags_changed (TubaApplication* _sender,
                                                                                                            const gchar* tag,
                                                                                                            gpointer self);
VALA_EXTERN gboolean tuba_widgets_status_action_button_get_active (TubaWidgetsStatusActionButton* self);
VALA_EXTERN void tuba_widgets_status_action_button_set_active (TubaWidgetsStatusActionButton* self,
                                                   gboolean value);
static const gchar* tuba_views_hashtags_favorite_tag_favorite_button_get_tag (TubaViewsHashtagsFavoriteTagFavoriteButton* self);
static gboolean tuba_views_hashtags_favorite_tag_favorite_button_get_force_recheck (TubaViewsHashtagsFavoriteTagFavoriteButton* self);
static void tuba_views_hashtags_favorite_tag_favorite_button_finalize (GObject * obj);
static GType tuba_views_hashtags_favorite_tag_favorite_button_get_type_once (void);
static void _vala_tuba_views_hashtags_favorite_tag_favorite_button_get_property (GObject * object,
                                                                          guint property_id,
                                                                          GValue * value,
                                                                          GParamSpec * pspec);
static void _vala_tuba_views_hashtags_favorite_tag_favorite_button_set_property (GObject * object,
                                                                          guint property_id,
                                                                          const GValue * value,
                                                                          GParamSpec * pspec);
static void tuba_views_hashtags_favorite_tag_finalize (GObject * obj);
static GType tuba_views_hashtags_favorite_tag_get_type_once (void);
static void _vala_tuba_views_hashtags_favorite_tag_get_property (GObject * object,
                                                          guint property_id,
                                                          GValue * value,
                                                          GParamSpec * pspec);
static void _vala_tuba_views_hashtags_favorite_tag_set_property (GObject * object,
                                                          guint property_id,
                                                          const GValue * value,
                                                          GParamSpec * pspec);
static GObject * tuba_views_hashtags_constructor (GType type,
                                           guint n_construct_properties,
                                           GObjectConstructParam * construct_properties);
VALA_EXTERN void tuba_views_timeline_set_accepts (TubaViewsTimeline* self,
                                      GType value);
static GType tuba_views_hashtags_get_type_once (void);
static void _vala_array_destroy (gpointer array,
                          gssize array_length,
                          GDestroyNotify destroy_func);
static void _vala_array_free (gpointer array,
                       gssize array_length,
                       GDestroyNotify destroy_func);

TubaViewsHashtags*
tuba_views_hashtags_construct (GType object_type)
{
	TubaViewsHashtags * self = NULL;
	self = (TubaViewsHashtags*) g_object_new (object_type, "url", "/api/v1/followed_tags", "label", _ ("Hashtags"), "icon", "tuba-hashtag-symbolic", "empty-state-title", _ ("No Hashtags"), "batch-size-min", 200, NULL);
	return self;
}

TubaViewsHashtags*
tuba_views_hashtags_new (void)
{
	return tuba_views_hashtags_construct (TUBA_VIEWS_TYPE_HASHTAGS);
}

static gint
_tuba_views_hashtags_compare_hashtags_gcompare_data_func (gconstpointer a,
                                                          gconstpointer b,
                                                          gpointer self)
{
	gint result;
	result = tuba_views_hashtags_compare_hashtags ((GObject*) a, (GObject*) b);
	return result;
}

static void
tuba_views_hashtags_real_on_request_finish (TubaViewsTimeline* base)
{
	TubaViewsHashtags * self;
	gboolean _tmp0_;
	gboolean _tmp1_;
	self = (TubaViewsHashtags*) base;
	_tmp0_ = tuba_views_timeline_get_has_finished_request ((TubaViewsTimeline*) self);
	_tmp1_ = _tmp0_;
	if (!_tmp1_) {
		GListStore* _tmp2_;
		_tmp2_ = ((TubaViewsContentBase*) self)->model;
		g_list_store_sort (_tmp2_, _tuba_views_hashtags_compare_hashtags_gcompare_data_func, NULL);
	}
	TUBA_VIEWS_TIMELINE_CLASS (tuba_views_hashtags_parent_class)->on_request_finish (G_TYPE_CHECK_INSTANCE_CAST (self, TUBA_VIEWS_TYPE_TIMELINE, TubaViewsTimeline));
}

static gint
tuba_views_hashtags_compare_hashtags (GObject* a,
                                      GObject* b)
{
	TubaViewsHashtagsFavoriteTag* fa = NULL;
	TubaViewsHashtagsFavoriteTag* fb = NULL;
	gint _tmp0_ = 0;
	gboolean _tmp1_ = FALSE;
	gboolean _tmp2_ = FALSE;
	TubaViewsHashtagsFavoriteTag* _tmp3_;
	TubaDialogsHashtagListData* _tmp4_;
	TubaDialogsHashtagListData* _tmp5_;
	gint result;
	g_return_val_if_fail (a != NULL, -1);
	g_return_val_if_fail (b != NULL, -1);
	fa = G_TYPE_CHECK_INSTANCE_CAST (a, TUBA_VIEWS_HASHTAGS_TYPE_FAVORITE_TAG, TubaViewsHashtagsFavoriteTag);
	fb = G_TYPE_CHECK_INSTANCE_CAST (b, TUBA_VIEWS_HASHTAGS_TYPE_FAVORITE_TAG, TubaViewsHashtagsFavoriteTag);
	_tmp3_ = fa;
	_tmp4_ = tuba_views_hashtags_favorite_tag_get_tuba_hashtag_data (_tmp3_);
	_tmp5_ = _tmp4_;
	if (_tmp5_ == NULL) {
		TubaViewsHashtagsFavoriteTag* _tmp6_;
		TubaDialogsHashtagListData* _tmp7_;
		TubaDialogsHashtagListData* _tmp8_;
		_tmp6_ = fb;
		_tmp7_ = tuba_views_hashtags_favorite_tag_get_tuba_hashtag_data (_tmp6_);
		_tmp8_ = _tmp7_;
		_tmp2_ = _tmp8_ == NULL;
	} else {
		_tmp2_ = FALSE;
	}
	if (_tmp2_) {
		_tmp1_ = TRUE;
	} else {
		gboolean _tmp9_ = FALSE;
		TubaViewsHashtagsFavoriteTag* _tmp10_;
		TubaDialogsHashtagListData* _tmp11_;
		TubaDialogsHashtagListData* _tmp12_;
		_tmp10_ = fa;
		_tmp11_ = tuba_views_hashtags_favorite_tag_get_tuba_hashtag_data (_tmp10_);
		_tmp12_ = _tmp11_;
		if (_tmp12_ != NULL) {
			TubaViewsHashtagsFavoriteTag* _tmp13_;
			TubaDialogsHashtagListData* _tmp14_;
			TubaDialogsHashtagListData* _tmp15_;
			_tmp13_ = fb;
			_tmp14_ = tuba_views_hashtags_favorite_tag_get_tuba_hashtag_data (_tmp13_);
			_tmp15_ = _tmp14_;
			_tmp9_ = _tmp15_ != NULL;
		} else {
			_tmp9_ = FALSE;
		}
		_tmp1_ = _tmp9_;
	}
	if (_tmp1_) {
		GCompareFunc _tmp16_;
		TubaViewsHashtagsFavoriteTag* _tmp17_;
		const gchar* _tmp18_;
		const gchar* _tmp19_;
		gchar* _tmp20_;
		gchar* _tmp21_;
		TubaViewsHashtagsFavoriteTag* _tmp22_;
		const gchar* _tmp23_;
		const gchar* _tmp24_;
		gchar* _tmp25_;
		gchar* _tmp26_;
		_tmp16_ = ((GCompareFunc) g_strcmp0);
		_tmp17_ = fa;
		_tmp18_ = tuba_api_tag_get_name ((TubaAPITag*) _tmp17_);
		_tmp19_ = _tmp18_;
		_tmp20_ = g_utf8_strdown (_tmp19_, (gssize) -1);
		_tmp21_ = _tmp20_;
		_tmp22_ = fb;
		_tmp23_ = tuba_api_tag_get_name ((TubaAPITag*) _tmp22_);
		_tmp24_ = _tmp23_;
		_tmp25_ = g_utf8_strdown (_tmp24_, (gssize) -1);
		_tmp26_ = _tmp25_;
		_tmp0_ = _tmp16_ (_tmp21_, _tmp26_);
		_g_free0 (_tmp26_);
		_g_free0 (_tmp21_);
	} else {
		_tmp0_ = 0;
	}
	result = _tmp0_;
	return result;
}

static void
_tuba_views_hashtags_on_new_list_gtk_button_clicked (GtkButton* _sender,
                                                     gpointer self)
{
	tuba_views_hashtags_on_new_list ((TubaViewsHashtags*) self);
}

static void
tuba_views_hashtags_real_build_header (TubaViewsBase* base)
{
	TubaViewsHashtags * self;
	GtkButton* new_list = NULL;
	gchar* _tmp0_;
	gchar* _tmp1_;
	gchar** _tmp2_;
	gchar* _tmp3_;
	GtkButton* _tmp4_ = NULL;
	AdwHeaderBar* _tmp5_;
	self = (TubaViewsHashtags*) base;
	TUBA_VIEWS_BASE_CLASS (tuba_views_hashtags_parent_class)->build_header ((TubaViewsBase*) G_TYPE_CHECK_INSTANCE_CAST (self, TUBA_VIEWS_TYPE_TIMELINE, TubaViewsTimeline));
	_tmp0_ = g_strdup ("tuba-plus-large-symbolic");
	_tmp1_ = g_strdup ("flat");
	_tmp2_ = g_new0 (gchar*, 1 + 1);
	_tmp2_[0] = _tmp1_;
	_tmp3_ = g_strdup (_ ("New Hashtag List"));
	_tmp4_ = (GtkButton*) gtk_button_new ();
	gtk_button_set_icon_name (_tmp4_, _tmp0_);
	_g_free0 (_tmp0_);
	gtk_widget_set_valign ((GtkWidget*) _tmp4_, GTK_ALIGN_CENTER);
	gtk_widget_set_halign ((GtkWidget*) _tmp4_, GTK_ALIGN_CENTER);
	gtk_widget_set_css_classes ((GtkWidget*) _tmp4_, _tmp2_);
	_tmp2_ = (_vala_array_free (_tmp2_, 1, (GDestroyNotify) g_free), NULL);
	gtk_widget_set_tooltip_text ((GtkWidget*) _tmp4_, _tmp3_);
	_g_free0 (_tmp3_);
	g_object_ref_sink (_tmp4_);
	new_list = _tmp4_;
	g_signal_connect_object (new_list, "clicked", (GCallback) _tuba_views_hashtags_on_new_list_gtk_button_clicked, self, 0);
	_tmp5_ = ((TubaViewsBase*) self)->header;
	adw_header_bar_pack_end (_tmp5_, (GtkWidget*) new_list);
	_g_object_unref0 (new_list);
}

static void
_tuba_views_hashtags_on_created_list_tuba_dialogs_hashtag_list_created (TubaDialogsHashtagList* _sender,
                                                                        gpointer self)
{
	tuba_views_hashtags_on_created_list ((TubaViewsHashtags*) self);
}

static void
tuba_views_hashtags_on_new_list (TubaViewsHashtags* self)
{
	TubaDialogsHashtagList* dlg = NULL;
	TubaDialogsHashtagList* _tmp0_;
	TubaApplication* _tmp1_;
	TubaDialogsMainWindow* _tmp2_;
	TubaDialogsMainWindow* _tmp3_;
	g_return_if_fail (self != NULL);
	_tmp0_ = tuba_dialogs_hashtag_list_new (NULL);
	g_object_ref_sink (_tmp0_);
	dlg = _tmp0_;
	g_signal_connect_object (dlg, "created", (GCallback) _tuba_views_hashtags_on_created_list_tuba_dialogs_hashtag_list_created, self, 0);
	_tmp1_ = tuba_app;
	_tmp2_ = tuba_application_get_main_window (_tmp1_);
	_tmp3_ = _tmp2_;
	adw_dialog_present ((AdwDialog*) dlg, (GtkWidget*) _tmp3_);
	_g_object_unref0 (dlg);
}

static void
tuba_views_hashtags_on_created_list (TubaViewsHashtags* self)
{
	g_return_if_fail (self != NULL);
	tuba_views_timeline_on_refresh ((TubaViewsTimeline*) self);
}

static gboolean
_tuba_views_hashtags_load_hashtag_lists_gsource_func (gpointer self)
{
	gboolean result;
	result = tuba_views_hashtags_load_hashtag_lists ((TubaViewsHashtags*) self);
	return result;
}

static void
tuba_views_hashtags_real_on_refresh (TubaViewsTimeline* base)
{
	TubaViewsHashtags * self;
	self = (TubaViewsHashtags*) base;
	TUBA_VIEWS_TIMELINE_CLASS (tuba_views_hashtags_parent_class)->on_refresh (G_TYPE_CHECK_INSTANCE_CAST (self, TUBA_VIEWS_TYPE_TIMELINE, TubaViewsTimeline));
	g_idle_add_full (G_PRIORITY_DEFAULT_IDLE, _tuba_views_hashtags_load_hashtag_lists_gsource_func, g_object_ref (self), g_object_unref);
}

static gpointer
_g_object_ref0 (gpointer self)
{
	return self ? g_object_ref (self) : NULL;
}

static void
_vala_array_add85 (GObject** * array,
                   gint* length,
                   gint* size,
                   GObject* value)
{
	if ((*length) == (*size)) {
		*size = (*size) ? (2 * (*size)) : 4;
		*array = g_renew (GObject*, *array, (*size) + 1);
	}
	(*array)[(*length)++] = value;
	(*array)[*length] = NULL;
}

gboolean
tuba_views_hashtags_load_hashtag_lists (TubaViewsHashtags* self)
{
	GObject** to_add = NULL;
	GObject** _tmp0_;
	gint to_add_length1;
	gint _to_add_size_;
	TubaSettings* _tmp1_;
	gchar** _tmp2_;
	gint _tmp2__length1;
	gint _tmp3_ = 0;
	gchar** _tmp4_;
	gint _tmp4__length1;
	GObject** _tmp15_;
	gint _tmp15__length1;
	gboolean result;
	g_return_val_if_fail (self != NULL, FALSE);
	_tmp0_ = g_new0 (GObject*, 0 + 1);
	to_add = _tmp0_;
	to_add_length1 = 0;
	_to_add_size_ = to_add_length1;
	_tmp1_ = tuba_settings;
	_tmp2_ = tuba_settings_get_hashtag_lists (_tmp1_, &_tmp3_);
	_tmp2__length1 = _tmp3_;
	_tmp4_ = _tmp2_;
	_tmp4__length1 = _tmp2__length1;
	{
		gchar** tag_list_collection = NULL;
		gint tag_list_collection_length1 = 0;
		gint _tag_list_collection_size_ = 0;
		gint tag_list_it = 0;
		tag_list_collection = _tmp4_;
		tag_list_collection_length1 = _tmp4__length1;
		for (tag_list_it = 0; tag_list_it < tag_list_collection_length1; tag_list_it = tag_list_it + 1) {
			gchar* _tmp5_;
			gchar* tag_list = NULL;
			_tmp5_ = g_strdup (tag_list_collection[tag_list_it]);
			tag_list = _tmp5_;
			{
				TubaDialogsHashtagListData* data = NULL;
				const gchar* _tmp6_;
				TubaDialogsHashtagListData* _tmp7_;
				TubaDialogsHashtagListData* _tmp8_;
				const gchar* _tmp9_;
				const gchar* _tmp10_;
				gchar* _tmp11_;
				TubaDialogsHashtagListData* _tmp12_;
				TubaDialogsHashtagListData* _tmp13_;
				TubaViewsHashtagsFavoriteTag* _tmp14_ = NULL;
				_tmp6_ = tag_list;
				_tmp7_ = tuba_dialogs_hashtag_list_data_new_from_string (_tmp6_);
				data = _tmp7_;
				_tmp8_ = data;
				_tmp9_ = tuba_dialogs_hashtag_list_data_get_title (_tmp8_);
				_tmp10_ = _tmp9_;
				_tmp11_ = g_strdup (_tmp10_);
				_tmp12_ = data;
				_tmp13_ = _g_object_ref0 (_tmp12_);
				_tmp14_ = tuba_views_hashtags_favorite_tag_new ();
				tuba_api_tag_set_name ((TubaAPITag*) _tmp14_, _tmp11_);
				_g_free0 (_tmp11_);
				tuba_views_hashtags_favorite_tag_set_tuba_hashtag_data (_tmp14_, _tmp13_);
				_g_object_unref0 (_tmp13_);
				_vala_array_add85 (&to_add, &to_add_length1, &_to_add_size_, (GObject*) _tmp14_);
				_g_object_unref0 (data);
				_g_free0 (tag_list);
			}
		}
	}
	_tmp15_ = to_add;
	_tmp15__length1 = to_add_length1;
	if (_tmp15__length1 > 0) {
		GListStore* _tmp16_;
		GObject** _tmp17_;
		gint _tmp17__length1;
		_tmp16_ = ((TubaViewsContentBase*) self)->model;
		_tmp17_ = to_add;
		_tmp17__length1 = to_add_length1;
		g_list_store_splice (_tmp16_, (guint) 0, (guint) 0, _tmp17_, (guint) _tmp17__length1);
	}
	result = G_SOURCE_REMOVE;
	to_add = (_vala_array_free (to_add, to_add_length1, (GDestroyNotify) g_object_unref), NULL);
	return result;
}

static gboolean
_vala_string_array_contains (gchar* * stack,
                             gssize stack_length,
                             const gchar* needle)
{
	gssize i;
	for (i = 0; i < stack_length; i++) {
		if (g_strcmp0 (stack[i], needle) == 0) {
			return TRUE;
		}
	}
	return FALSE;
}

static void
_vala_array_add86 (gchar** * array,
                   gint* length,
                   gint* size,
                   gchar* value)
{
	if ((*length) == (*size)) {
		*size = (*size) ? (2 * (*size)) : 4;
		*array = g_renew (gchar*, *array, (*size) + 1);
	}
	(*array)[(*length)++] = value;
	(*array)[*length] = NULL;
}

static void
_vala_array_add87 (gchar** * array,
                   gint* length,
                   gint* size,
                   gchar* value)
{
	if ((*length) == (*size)) {
		*size = (*size) ? (2 * (*size)) : 4;
		*array = g_renew (gchar*, *array, (*size) + 1);
	}
	(*array)[(*length)++] = value;
	(*array)[*length] = NULL;
}

static gboolean
_tuba_instance_account_gather_fav_tags_gsource_func (gpointer self)
{
	gboolean result;
	result = tuba_instance_account_gather_fav_tags ((TubaInstanceAccount*) self);
	return result;
}

void
tuba_views_hashtags_add_tag_to_favs (const gchar* name)
{
	TubaSettings* _tmp0_;
	gchar** _tmp1_;
	gint _tmp1__length1;
	gint _tmp2_ = 0;
	gchar** _tmp3_;
	gint _tmp3__length1;
	gchar** res = NULL;
	gchar** _tmp4_;
	gint res_length1;
	gint _res_size_;
	gchar* down_name = NULL;
	gchar* _tmp5_;
	TubaSettings* _tmp6_;
	gchar** _tmp7_;
	gint _tmp7__length1;
	gint _tmp8_ = 0;
	gchar** _tmp9_;
	gint _tmp9__length1;
	gchar* _tmp18_;
	TubaSettings* _tmp19_;
	gchar** _tmp20_;
	gint _tmp20__length1;
	TubaAccountStore* _tmp21_;
	TubaInstanceAccount* _tmp22_;
	TubaInstanceAccount* _tmp23_;
	g_return_if_fail (name != NULL);
	_tmp0_ = tuba_settings;
	_tmp1_ = tuba_settings_get_favorite_tags_ids (_tmp0_, &_tmp2_);
	_tmp1__length1 = _tmp2_;
	_tmp3_ = _tmp1_;
	_tmp3__length1 = _tmp1__length1;
	if (_vala_string_array_contains (_tmp3_, _tmp3__length1, name)) {
		return;
	}
	_tmp4_ = g_new0 (gchar*, 0 + 1);
	res = _tmp4_;
	res_length1 = 0;
	_res_size_ = res_length1;
	_tmp5_ = g_utf8_strdown (name, (gssize) -1);
	down_name = _tmp5_;
	_tmp6_ = tuba_settings;
	_tmp7_ = tuba_settings_get_favorite_tags_ids (_tmp6_, &_tmp8_);
	_tmp7__length1 = _tmp8_;
	_tmp9_ = _tmp7_;
	_tmp9__length1 = _tmp7__length1;
	{
		gchar** tag_name_collection = NULL;
		gint tag_name_collection_length1 = 0;
		gint _tag_name_collection_size_ = 0;
		gint tag_name_it = 0;
		tag_name_collection = _tmp9_;
		tag_name_collection_length1 = _tmp9__length1;
		for (tag_name_it = 0; tag_name_it < tag_name_collection_length1; tag_name_it = tag_name_it + 1) {
			gchar* _tmp10_;
			gchar* tag_name = NULL;
			_tmp10_ = g_strdup (tag_name_collection[tag_name_it]);
			tag_name = _tmp10_;
			{
				const gchar* _tmp11_;
				gchar* _tmp12_;
				gchar* _tmp13_;
				const gchar* _tmp14_;
				gboolean _tmp15_;
				_tmp11_ = tag_name;
				_tmp12_ = g_utf8_strdown (_tmp11_, (gssize) -1);
				_tmp13_ = _tmp12_;
				_tmp14_ = down_name;
				_tmp15_ = g_strcmp0 (_tmp13_, _tmp14_) != 0;
				_g_free0 (_tmp13_);
				if (_tmp15_) {
					const gchar* _tmp16_;
					gchar* _tmp17_;
					_tmp16_ = tag_name;
					_tmp17_ = g_strdup (_tmp16_);
					_vala_array_add86 (&res, &res_length1, &_res_size_, _tmp17_);
				}
				_g_free0 (tag_name);
			}
		}
	}
	_tmp18_ = g_strdup (name);
	_vala_array_add87 (&res, &res_length1, &_res_size_, _tmp18_);
	_tmp19_ = tuba_settings;
	_tmp20_ = res;
	_tmp20__length1 = res_length1;
	tuba_settings_set_favorite_tags_ids (_tmp19_, _tmp20_, _tmp20__length1);
	_tmp21_ = tuba_accounts;
	_tmp22_ = tuba_account_store_get_active (_tmp21_);
	_tmp23_ = _tmp22_;
	g_idle_add_full (G_PRIORITY_DEFAULT_IDLE, _tuba_instance_account_gather_fav_tags_gsource_func, g_object_ref (_tmp23_), g_object_unref);
	_g_free0 (down_name);
	res = (_vala_array_free (res, res_length1, (GDestroyNotify) g_free), NULL);
}

static void
_vala_array_add88 (gchar** * array,
                   gint* length,
                   gint* size,
                   gchar* value)
{
	if ((*length) == (*size)) {
		*size = (*size) ? (2 * (*size)) : 4;
		*array = g_renew (gchar*, *array, (*size) + 1);
	}
	(*array)[(*length)++] = value;
	(*array)[*length] = NULL;
}

void
tuba_views_hashtags_remove_tag_from_favs (const gchar* name)
{
	gboolean _tmp0_ = FALSE;
	TubaSettings* _tmp1_;
	gchar** _tmp2_;
	gint _tmp2__length1;
	gint _tmp3_ = 0;
	gchar** _tmp4_;
	gint _tmp4__length1;
	gchar** new_ids = NULL;
	gchar** _tmp9_;
	gint new_ids_length1;
	gint _new_ids_size_;
	gchar* down_name = NULL;
	gchar* _tmp10_;
	TubaSettings* _tmp11_;
	gchar** _tmp12_;
	gint _tmp12__length1;
	gint _tmp13_ = 0;
	gchar** _tmp14_;
	gint _tmp14__length1;
	TubaSettings* _tmp23_;
	gchar** _tmp24_;
	gint _tmp24__length1;
	TubaAccountStore* _tmp25_;
	TubaInstanceAccount* _tmp26_;
	TubaInstanceAccount* _tmp27_;
	g_return_if_fail (name != NULL);
	_tmp1_ = tuba_settings;
	_tmp2_ = tuba_settings_get_favorite_tags_ids (_tmp1_, &_tmp3_);
	_tmp2__length1 = _tmp3_;
	_tmp4_ = _tmp2_;
	_tmp4__length1 = _tmp2__length1;
	if (_tmp4__length1 == 0) {
		_tmp0_ = TRUE;
	} else {
		TubaSettings* _tmp5_;
		gchar** _tmp6_;
		gint _tmp6__length1;
		gint _tmp7_ = 0;
		gchar** _tmp8_;
		gint _tmp8__length1;
		_tmp5_ = tuba_settings;
		_tmp6_ = tuba_settings_get_favorite_tags_ids (_tmp5_, &_tmp7_);
		_tmp6__length1 = _tmp7_;
		_tmp8_ = _tmp6_;
		_tmp8__length1 = _tmp6__length1;
		_tmp0_ = !_vala_string_array_contains (_tmp8_, _tmp8__length1, name);
	}
	if (_tmp0_) {
		return;
	}
	_tmp9_ = g_new0 (gchar*, 0 + 1);
	new_ids = _tmp9_;
	new_ids_length1 = 0;
	_new_ids_size_ = new_ids_length1;
	_tmp10_ = g_utf8_strdown (name, (gssize) -1);
	down_name = _tmp10_;
	_tmp11_ = tuba_settings;
	_tmp12_ = tuba_settings_get_favorite_tags_ids (_tmp11_, &_tmp13_);
	_tmp12__length1 = _tmp13_;
	_tmp14_ = _tmp12_;
	_tmp14__length1 = _tmp12__length1;
	{
		gchar** tag_name_collection = NULL;
		gint tag_name_collection_length1 = 0;
		gint _tag_name_collection_size_ = 0;
		gint tag_name_it = 0;
		tag_name_collection = _tmp14_;
		tag_name_collection_length1 = _tmp14__length1;
		for (tag_name_it = 0; tag_name_it < tag_name_collection_length1; tag_name_it = tag_name_it + 1) {
			gchar* _tmp15_;
			gchar* tag_name = NULL;
			_tmp15_ = g_strdup (tag_name_collection[tag_name_it]);
			tag_name = _tmp15_;
			{
				const gchar* _tmp16_;
				const gchar* _tmp17_;
				gchar* _tmp18_;
				gchar* _tmp19_;
				gboolean _tmp20_;
				_tmp16_ = down_name;
				_tmp17_ = tag_name;
				_tmp18_ = g_utf8_strdown (_tmp17_, (gssize) -1);
				_tmp19_ = _tmp18_;
				_tmp20_ = g_strcmp0 (_tmp16_, _tmp19_) != 0;
				_g_free0 (_tmp19_);
				if (_tmp20_) {
					const gchar* _tmp21_;
					gchar* _tmp22_;
					_tmp21_ = tag_name;
					_tmp22_ = g_strdup (_tmp21_);
					_vala_array_add88 (&new_ids, &new_ids_length1, &_new_ids_size_, _tmp22_);
				}
				_g_free0 (tag_name);
			}
		}
	}
	_tmp23_ = tuba_settings;
	_tmp24_ = new_ids;
	_tmp24__length1 = new_ids_length1;
	tuba_settings_set_favorite_tags_ids (_tmp23_, _tmp24_, _tmp24__length1);
	_tmp25_ = tuba_accounts;
	_tmp26_ = tuba_account_store_get_active (_tmp25_);
	_tmp27_ = _tmp26_;
	g_idle_add_full (G_PRIORITY_DEFAULT_IDLE, _tuba_instance_account_gather_fav_tags_gsource_func, g_object_ref (_tmp27_), g_object_unref);
	_g_free0 (down_name);
	new_ids = (_vala_array_free (new_ids, new_ids_length1, (GDestroyNotify) g_free), NULL);
}

static const gchar*
string_to_string (const gchar* self)
{
	const gchar* result;
	g_return_val_if_fail (self != NULL, NULL);
	result = self;
	return result;
}

TubaViewsHashtagsHashtagList*
tuba_views_hashtags_hashtag_list_construct (GType object_type,
                                            const gchar* title,
                                            const gchar* uri_part)
{
	TubaViewsHashtagsHashtagList * self = NULL;
	const gchar* _tmp0_;
	gchar* _tmp1_;
	gchar* _tmp2_;
	g_return_val_if_fail (title != NULL, NULL);
	g_return_val_if_fail (uri_part != NULL, NULL);
	_tmp0_ = string_to_string (uri_part);
	_tmp1_ = g_strconcat ("/api/v1/timelines/tag/", _tmp0_, NULL);
	_tmp2_ = _tmp1_;
	self = (TubaViewsHashtagsHashtagList*) g_object_new (object_type, "uid", 3, "url", _tmp2_, "label", title, "icon", "tuba-list-compact-symbolic", NULL);
	_g_free0 (_tmp2_);
	return self;
}

TubaViewsHashtagsHashtagList*
tuba_views_hashtags_hashtag_list_new (const gchar* title,
                                      const gchar* uri_part)
{
	return tuba_views_hashtags_hashtag_list_construct (TUBA_VIEWS_HASHTAGS_TYPE_HASHTAG_LIST, title, uri_part);
}

static void
tuba_views_hashtags_hashtag_list_class_init (TubaViewsHashtagsHashtagListClass * klass,
                                             gpointer klass_data)
{
	tuba_views_hashtags_hashtag_list_parent_class = g_type_class_peek_parent (klass);
}

static void
tuba_views_hashtags_hashtag_list_instance_init (TubaViewsHashtagsHashtagList * self,
                                                gpointer klass)
{
}

 G_GNUC_NO_INLINE static GType
tuba_views_hashtags_hashtag_list_get_type_once (void)
{
	static const GTypeInfo g_define_type_info = { sizeof (TubaViewsHashtagsHashtagListClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) tuba_views_hashtags_hashtag_list_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (TubaViewsHashtagsHashtagList), 0, (GInstanceInitFunc) tuba_views_hashtags_hashtag_list_instance_init, NULL };
	GType tuba_views_hashtags_hashtag_list_type_id;
	tuba_views_hashtags_hashtag_list_type_id = g_type_register_static (TUBA_VIEWS_TYPE_TIMELINE, "TubaViewsHashtagsHashtagList", &g_define_type_info, G_TYPE_FLAG_NONE);
	return tuba_views_hashtags_hashtag_list_type_id;
}

GType
tuba_views_hashtags_hashtag_list_get_type (void)
{
	static GType tuba_views_hashtags_hashtag_list_type_id__once = 0;
	if (g_once_init_enter_pointer (&tuba_views_hashtags_hashtag_list_type_id__once)) {
		GType tuba_views_hashtags_hashtag_list_type_id;
		tuba_views_hashtags_hashtag_list_type_id = tuba_views_hashtags_hashtag_list_get_type_once ();
		g_once_init_leave_pointer (&tuba_views_hashtags_hashtag_list_type_id__once, tuba_views_hashtags_hashtag_list_type_id);
	}
	return tuba_views_hashtags_hashtag_list_type_id__once;
}

static inline gpointer
tuba_views_hashtags_favorite_tag_get_instance_private (TubaViewsHashtagsFavoriteTag* self)
{
	return G_STRUCT_MEMBER_P (self, TubaViewsHashtagsFavoriteTag_private_offset);
}

static void
_tuba_views_hashtags_favorite_tag_on_edit_hashtag_list_gtk_button_clicked (GtkButton* _sender,
                                                                           gpointer self)
{
	tuba_views_hashtags_favorite_tag_on_edit_hashtag_list ((TubaViewsHashtagsFavoriteTag*) self);
}

static void
_tuba_views_hashtags_favorite_tag_on_remove_hl_clicked_gtk_button_clicked (GtkButton* _sender,
                                                                           gpointer self)
{
	tuba_views_hashtags_favorite_tag_on_remove_hl_clicked ((TubaViewsHashtagsFavoriteTag*) self);
}

static GtkWidget*
tuba_views_hashtags_favorite_tag_real_to_widget (TubaWidgetizable* base)
{
	TubaViewsHashtagsFavoriteTag * self;
	AdwActionRow* row = NULL;
	GtkWidget* _tmp0_;
	TubaDialogsHashtagListData* _tmp1_;
	GtkWidget* result;
	self = (TubaViewsHashtagsFavoriteTag*) base;
	_tmp0_ = tuba_views_hashtags_favorite_tag_tuba_widgetizable_parent_iface->to_widget ((TubaWidgetizable*) G_TYPE_CHECK_INSTANCE_CAST (self, TUBA_API_TYPE_TAG, TubaAPITag));
	row = G_TYPE_CHECK_INSTANCE_CAST (_tmp0_, adw_action_row_get_type (), AdwActionRow);
	_tmp1_ = self->priv->_tuba_hashtag_data;
	if (_tmp1_ == NULL) {
		AdwActionRow* _tmp2_;
		const gchar* _tmp3_;
		const gchar* _tmp4_;
		TubaViewsHashtagsFavoriteTagFavoriteButton* _tmp5_;
		TubaViewsHashtagsFavoriteTagFavoriteButton* _tmp6_;
		_tmp2_ = row;
		_tmp3_ = tuba_api_tag_get_name ((TubaAPITag*) self);
		_tmp4_ = _tmp3_;
		_tmp5_ = tuba_views_hashtags_favorite_tag_favorite_button_new (_tmp4_, TRUE);
		g_object_ref_sink (_tmp5_);
		_tmp6_ = _tmp5_;
		adw_action_row_add_prefix (_tmp2_, (GtkWidget*) _tmp6_);
		_g_object_unref0 (_tmp6_);
	} else {
		AdwActionRow* _tmp7_;
		TubaDialogsHashtagListData* _tmp8_;
		gchar* _tmp9_;
		gchar* _tmp10_;
		AdwActionRow* _tmp11_;
		GtkImage* _tmp12_ = NULL;
		GtkImage* _tmp13_;
		GtkButton* edit_button = NULL;
		gchar* _tmp14_;
		gchar* _tmp15_;
		gchar* _tmp16_;
		gchar** _tmp17_;
		gchar* _tmp18_;
		GtkButton* _tmp19_ = NULL;
		GtkButton* _tmp20_;
		AdwActionRow* _tmp21_;
		GtkButton* _tmp22_;
		GtkButton* delete_button = NULL;
		gchar* _tmp23_;
		gchar* _tmp24_;
		gchar* _tmp25_;
		gchar* _tmp26_;
		gchar** _tmp27_;
		gchar* _tmp28_;
		GtkButton* _tmp29_ = NULL;
		GtkButton* _tmp30_;
		AdwActionRow* _tmp31_;
		GtkButton* _tmp32_;
		_tmp7_ = row;
		_tmp8_ = self->priv->_tuba_hashtag_data;
		_tmp9_ = tuba_dialogs_hashtag_list_data_to_sub (_tmp8_);
		_tmp10_ = _tmp9_;
		adw_action_row_set_subtitle (_tmp7_, _tmp10_);
		_g_free0 (_tmp10_);
		_tmp11_ = row;
		_tmp12_ = (GtkImage*) gtk_image_new_from_icon_name ("tuba-list-compact-symbolic");
		gtk_widget_set_halign ((GtkWidget*) _tmp12_, GTK_ALIGN_CENTER);
		gtk_widget_set_valign ((GtkWidget*) _tmp12_, GTK_ALIGN_CENTER);
		gtk_widget_set_margin_start ((GtkWidget*) _tmp12_, 9);
		gtk_widget_set_margin_end ((GtkWidget*) _tmp12_, 9);
		g_object_ref_sink (_tmp12_);
		_tmp13_ = _tmp12_;
		adw_action_row_add_prefix (_tmp11_, (GtkWidget*) _tmp13_);
		_g_object_unref0 (_tmp13_);
		_tmp14_ = g_strdup ("document-edit-symbolic");
		_tmp15_ = g_strdup ("flat");
		_tmp16_ = g_strdup ("circular");
		_tmp17_ = g_new0 (gchar*, 2 + 1);
		_tmp17_[0] = _tmp15_;
		_tmp17_[1] = _tmp16_;
		_tmp18_ = g_strdup (_ ("Edit"));
		_tmp19_ = (GtkButton*) gtk_button_new ();
		gtk_button_set_icon_name (_tmp19_, _tmp14_);
		_g_free0 (_tmp14_);
		gtk_widget_set_valign ((GtkWidget*) _tmp19_, GTK_ALIGN_CENTER);
		gtk_widget_set_halign ((GtkWidget*) _tmp19_, GTK_ALIGN_CENTER);
		gtk_widget_set_css_classes ((GtkWidget*) _tmp19_, _tmp17_);
		_tmp17_ = (_vala_array_free (_tmp17_, 2, (GDestroyNotify) g_free), NULL);
		gtk_widget_set_tooltip_text ((GtkWidget*) _tmp19_, _tmp18_);
		_g_free0 (_tmp18_);
		g_object_ref_sink (_tmp19_);
		edit_button = _tmp19_;
		_tmp20_ = edit_button;
		g_signal_connect_object (_tmp20_, "clicked", (GCallback) _tuba_views_hashtags_favorite_tag_on_edit_hashtag_list_gtk_button_clicked, self, 0);
		_tmp21_ = row;
		_tmp22_ = edit_button;
		adw_action_row_add_suffix (_tmp21_, (GtkWidget*) _tmp22_);
		_tmp23_ = g_strdup ("user-trash-symbolic");
		_tmp24_ = g_strdup ("flat");
		_tmp25_ = g_strdup ("circular");
		_tmp26_ = g_strdup ("error");
		_tmp27_ = g_new0 (gchar*, 3 + 1);
		_tmp27_[0] = _tmp24_;
		_tmp27_[1] = _tmp25_;
		_tmp27_[2] = _tmp26_;
		_tmp28_ = g_strdup (_ ("Delete"));
		_tmp29_ = (GtkButton*) gtk_button_new ();
		gtk_button_set_icon_name (_tmp29_, _tmp23_);
		_g_free0 (_tmp23_);
		gtk_widget_set_valign ((GtkWidget*) _tmp29_, GTK_ALIGN_CENTER);
		gtk_widget_set_halign ((GtkWidget*) _tmp29_, GTK_ALIGN_CENTER);
		gtk_widget_set_css_classes ((GtkWidget*) _tmp29_, _tmp27_);
		_tmp27_ = (_vala_array_free (_tmp27_, 3, (GDestroyNotify) g_free), NULL);
		gtk_widget_set_tooltip_text ((GtkWidget*) _tmp29_, _tmp28_);
		_g_free0 (_tmp28_);
		g_object_ref_sink (_tmp29_);
		delete_button = _tmp29_;
		_tmp30_ = delete_button;
		g_signal_connect_object (_tmp30_, "clicked", (GCallback) _tuba_views_hashtags_favorite_tag_on_remove_hl_clicked_gtk_button_clicked, self, 0);
		_tmp31_ = row;
		_tmp32_ = delete_button;
		adw_action_row_add_suffix (_tmp31_, (GtkWidget*) _tmp32_);
		_g_object_unref0 (delete_button);
		_g_object_unref0 (edit_button);
	}
	result = (GtkWidget*) row;
	return result;
}

static void
tuba_views_hashtags_favorite_tag_real_on_activated (TubaAPITag* base)
{
	TubaViewsHashtagsFavoriteTag * self;
	TubaDialogsHashtagListData* _tmp0_;
	self = (TubaViewsHashtagsFavoriteTag*) base;
	_tmp0_ = self->priv->_tuba_hashtag_data;
	if (_tmp0_ == NULL) {
		TUBA_API_TAG_CLASS (tuba_views_hashtags_favorite_tag_parent_class)->on_activated (G_TYPE_CHECK_INSTANCE_CAST (self, TUBA_API_TYPE_TAG, TubaAPITag));
	} else {
		TubaApplication* _tmp1_;
		TubaDialogsMainWindow* _tmp2_;
		TubaDialogsMainWindow* _tmp3_;
		TubaDialogsHashtagListData* _tmp4_;
		const gchar* _tmp5_;
		const gchar* _tmp6_;
		TubaDialogsHashtagListData* _tmp7_;
		gchar* _tmp8_;
		gchar* _tmp9_;
		TubaViewsHashtagsHashtagList* _tmp10_;
		TubaViewsHashtagsHashtagList* _tmp11_;
		TubaViewsBase* _tmp12_;
		TubaViewsBase* _tmp13_;
		_tmp1_ = tuba_app;
		_tmp2_ = tuba_application_get_main_window (_tmp1_);
		_tmp3_ = _tmp2_;
		_tmp4_ = self->priv->_tuba_hashtag_data;
		_tmp5_ = tuba_dialogs_hashtag_list_data_get_title (_tmp4_);
		_tmp6_ = _tmp5_;
		_tmp7_ = self->priv->_tuba_hashtag_data;
		_tmp8_ = tuba_dialogs_hashtag_list_data_to_uri_part (_tmp7_);
		_tmp9_ = _tmp8_;
		_tmp10_ = tuba_views_hashtags_hashtag_list_new (_tmp6_, _tmp9_);
		g_object_ref_sink (_tmp10_);
		_tmp11_ = _tmp10_;
		_tmp12_ = tuba_dialogs_main_window_open_view (_tmp3_, (TubaViewsBase*) _tmp11_);
		_tmp13_ = _tmp12_;
		_g_object_unref0 (_tmp13_);
		_g_object_unref0 (_tmp11_);
		_g_free0 (_tmp9_);
	}
}

static void
_tuba_views_hashtags_favorite_tag_on_edited_list_tuba_dialogs_hashtag_list_created (TubaDialogsHashtagList* _sender,
                                                                                    gpointer self)
{
	tuba_views_hashtags_favorite_tag_on_edited_list ((TubaViewsHashtagsFavoriteTag*) self);
}

static void
tuba_views_hashtags_favorite_tag_on_edit_hashtag_list (TubaViewsHashtagsFavoriteTag* self)
{
	TubaDialogsHashtagList* dlg = NULL;
	TubaDialogsHashtagListData* _tmp0_;
	TubaDialogsHashtagList* _tmp1_;
	TubaApplication* _tmp2_;
	TubaDialogsMainWindow* _tmp3_;
	TubaDialogsMainWindow* _tmp4_;
	g_return_if_fail (self != NULL);
	_tmp0_ = self->priv->_tuba_hashtag_data;
	_tmp1_ = tuba_dialogs_hashtag_list_new (_tmp0_);
	g_object_ref_sink (_tmp1_);
	dlg = _tmp1_;
	g_signal_connect_object (dlg, "created", (GCallback) _tuba_views_hashtags_favorite_tag_on_edited_list_tuba_dialogs_hashtag_list_created, self, 0);
	_tmp2_ = tuba_app;
	_tmp3_ = tuba_application_get_main_window (_tmp2_);
	_tmp4_ = _tmp3_;
	adw_dialog_present ((AdwDialog*) dlg, (GtkWidget*) _tmp4_);
	_g_object_unref0 (dlg);
}

static void
tuba_views_hashtags_favorite_tag_on_edited_list (TubaViewsHashtagsFavoriteTag* self)
{
	TubaApplication* _tmp0_;
	g_return_if_fail (self != NULL);
	_tmp0_ = tuba_app;
	g_signal_emit_by_name (_tmp0_, "refresh");
}

static void
tuba_views_hashtags_favorite_tag_on_remove_hl_clicked (TubaViewsHashtagsFavoriteTag* self)
{
	TubaDialogsHashtagListData* _tmp0_;
	const gchar* _tmp1_;
	const gchar* _tmp2_;
	TubaApplication* _tmp3_;
	g_return_if_fail (self != NULL);
	_tmp0_ = self->priv->_tuba_hashtag_data;
	_tmp1_ = tuba_dialogs_hashtag_list_data_get_uuid (_tmp0_);
	_tmp2_ = _tmp1_;
	tuba_dialogs_hashtag_list_remove_hashtag_list (_tmp2_);
	_tmp3_ = tuba_app;
	g_signal_emit_by_name (_tmp3_, "refresh");
}

TubaViewsHashtagsFavoriteTag*
tuba_views_hashtags_favorite_tag_construct (GType object_type)
{
	TubaViewsHashtagsFavoriteTag * self = NULL;
	self = (TubaViewsHashtagsFavoriteTag*) tuba_api_tag_construct (object_type);
	return self;
}

TubaViewsHashtagsFavoriteTag*
tuba_views_hashtags_favorite_tag_new (void)
{
	return tuba_views_hashtags_favorite_tag_construct (TUBA_VIEWS_HASHTAGS_TYPE_FAVORITE_TAG);
}

TubaDialogsHashtagListData*
tuba_views_hashtags_favorite_tag_get_tuba_hashtag_data (TubaViewsHashtagsFavoriteTag* self)
{
	TubaDialogsHashtagListData* result;
	TubaDialogsHashtagListData* _tmp0_;
	g_return_val_if_fail (self != NULL, NULL);
	_tmp0_ = self->priv->_tuba_hashtag_data;
	result = _tmp0_;
	return result;
}

void
tuba_views_hashtags_favorite_tag_set_tuba_hashtag_data (TubaViewsHashtagsFavoriteTag* self,
                                                        TubaDialogsHashtagListData* value)
{
	TubaDialogsHashtagListData* old_value;
	g_return_if_fail (self != NULL);
	old_value = tuba_views_hashtags_favorite_tag_get_tuba_hashtag_data (self);
	if (old_value != value) {
		TubaDialogsHashtagListData* _tmp0_;
		_tmp0_ = _g_object_ref0 (value);
		_g_object_unref0 (self->priv->_tuba_hashtag_data);
		self->priv->_tuba_hashtag_data = _tmp0_;
		g_object_notify_by_pspec ((GObject *) self, tuba_views_hashtags_favorite_tag_properties[TUBA_VIEWS_HASHTAGS_FAVORITE_TAG_TUBA_HASHTAG_DATA_PROPERTY]);
	}
}

static inline gpointer
tuba_views_hashtags_favorite_tag_favorite_button_get_instance_private (TubaViewsHashtagsFavoriteTagFavoriteButton* self)
{
	return G_STRUCT_MEMBER_P (self, TubaViewsHashtagsFavoriteTagFavoriteButton_private_offset);
}

static void
_tuba_views_hashtags_favorite_tag_favorite_button_on_favorite_button_clicked_gtk_button_clicked (GtkButton* _sender,
                                                                                                 gpointer self)
{
	tuba_views_hashtags_favorite_tag_favorite_button_on_favorite_button_clicked ((TubaViewsHashtagsFavoriteTagFavoriteButton*) self);
}

static void
_tuba_views_hashtags_favorite_tag_favorite_button_on_fav_tags_updated_g_object_notify (GObject* _sender,
                                                                                       GParamSpec* pspec,
                                                                                       gpointer self)
{
	tuba_views_hashtags_favorite_tag_favorite_button_on_fav_tags_updated ((TubaViewsHashtagsFavoriteTagFavoriteButton*) self);
}

static void
_tuba_views_hashtags_favorite_tag_favorite_button_update_fav_status_tuba_application_fav_tags_changed (TubaApplication* _sender,
                                                                                                       const gchar* tag,
                                                                                                       gpointer self)
{
	tuba_views_hashtags_favorite_tag_favorite_button_update_fav_status ((TubaViewsHashtagsFavoriteTagFavoriteButton*) self, tag);
}

TubaViewsHashtagsFavoriteTagFavoriteButton*
tuba_views_hashtags_favorite_tag_favorite_button_construct (GType object_type,
                                                            const gchar* tag,
                                                            gboolean force_recheck)
{
	TubaViewsHashtagsFavoriteTagFavoriteButton * self = NULL;
	gchar* _tmp0_;
	gchar* _tmp1_;
	gchar* _tmp2_;
	gchar** _tmp3_;
	gchar** _tmp4_;
	gint _tmp4__length1;
	TubaSettings* _tmp5_;
	g_return_val_if_fail (tag != NULL, NULL);
	self = (TubaViewsHashtagsFavoriteTagFavoriteButton*) g_object_new (object_type, "default-icon-name", "tuba-unstarred-symbolic", NULL);
	tuba_views_hashtags_favorite_tag_favorite_button_set_tag (self, tag);
	tuba_views_hashtags_favorite_tag_favorite_button_set_force_recheck (self, force_recheck);
	tuba_widgets_status_action_button_set_active_icon_name ((TubaWidgetsStatusActionButton*) self, "tuba-starred-symbolic");
	_tmp0_ = g_strdup ("ttl-status-action-star");
	_tmp1_ = g_strdup ("flat");
	_tmp2_ = g_strdup ("circular");
	_tmp3_ = g_new0 (gchar*, 3 + 1);
	_tmp3_[0] = _tmp0_;
	_tmp3_[1] = _tmp1_;
	_tmp3_[2] = _tmp2_;
	_tmp4_ = _tmp3_;
	_tmp4__length1 = 3;
	gtk_widget_set_css_classes ((GtkWidget*) self, _tmp4_);
	_tmp4_ = (_vala_array_free (_tmp4_, _tmp4__length1, (GDestroyNotify) g_free), NULL);
	gtk_widget_set_valign ((GtkWidget*) self, GTK_ALIGN_CENTER);
	gtk_widget_set_halign ((GtkWidget*) self, GTK_ALIGN_CENTER);
	gtk_widget_set_tooltip_text ((GtkWidget*) self, _ ("Favorite"));
	g_signal_connect_object ((GtkButton*) self, "clicked", (GCallback) _tuba_views_hashtags_favorite_tag_favorite_button_on_favorite_button_clicked_gtk_button_clicked, self, 0);
	_tmp5_ = tuba_settings;
	g_signal_connect_object ((GObject*) _tmp5_, "notify::favorite-tags-ids", (GCallback) _tuba_views_hashtags_favorite_tag_favorite_button_on_fav_tags_updated_g_object_notify, self, 0);
	tuba_views_hashtags_favorite_tag_favorite_button_update_fav_status (self, NULL);
	if (force_recheck) {
		TubaApplication* _tmp6_;
		_tmp6_ = tuba_app;
		g_signal_connect_object (_tmp6_, "fav-tags-changed", (GCallback) _tuba_views_hashtags_favorite_tag_favorite_button_update_fav_status_tuba_application_fav_tags_changed, self, 0);
	}
	return self;
}

TubaViewsHashtagsFavoriteTagFavoriteButton*
tuba_views_hashtags_favorite_tag_favorite_button_new (const gchar* tag,
                                                      gboolean force_recheck)
{
	return tuba_views_hashtags_favorite_tag_favorite_button_construct (TUBA_VIEWS_HASHTAGS_FAVORITE_TAG_TYPE_FAVORITE_BUTTON, tag, force_recheck);
}

static void
tuba_views_hashtags_favorite_tag_favorite_button_on_favorite_button_clicked (TubaViewsHashtagsFavoriteTagFavoriteButton* self)
{
	gboolean _tmp0_;
	gboolean _tmp1_;
	gboolean _tmp2_;
	gboolean _tmp3_;
	gboolean _tmp6_;
	g_return_if_fail (self != NULL);
	_tmp0_ = tuba_widgets_status_action_button_get_active ((TubaWidgetsStatusActionButton*) self);
	_tmp1_ = _tmp0_;
	tuba_widgets_status_action_button_set_active ((TubaWidgetsStatusActionButton*) self, !_tmp1_);
	_tmp2_ = tuba_widgets_status_action_button_get_active ((TubaWidgetsStatusActionButton*) self);
	_tmp3_ = _tmp2_;
	if (_tmp3_) {
		const gchar* _tmp4_;
		_tmp4_ = self->priv->_tag;
		tuba_views_hashtags_add_tag_to_favs (_tmp4_);
	} else {
		const gchar* _tmp5_;
		_tmp5_ = self->priv->_tag;
		tuba_views_hashtags_remove_tag_from_favs (_tmp5_);
	}
	_tmp6_ = self->priv->_force_recheck;
	if (!_tmp6_) {
		TubaApplication* _tmp7_;
		const gchar* _tmp8_;
		_tmp7_ = tuba_app;
		_tmp8_ = self->priv->_tag;
		g_signal_emit_by_name (_tmp7_, "fav-tags-changed", _tmp8_);
	}
}

static void
tuba_views_hashtags_favorite_tag_favorite_button_on_fav_tags_updated (TubaViewsHashtagsFavoriteTagFavoriteButton* self)
{
	gboolean _tmp0_ = FALSE;
	gboolean _tmp1_;
	gboolean _tmp2_;
	g_return_if_fail (self != NULL);
	_tmp1_ = tuba_widgets_status_action_button_get_active ((TubaWidgetsStatusActionButton*) self);
	_tmp2_ = _tmp1_;
	if (_tmp2_) {
		_tmp0_ = TRUE;
	} else {
		TubaSettings* _tmp3_;
		gchar** _tmp4_;
		gint _tmp4__length1;
		gint _tmp5_ = 0;
		gchar** _tmp6_;
		gint _tmp6__length1;
		_tmp3_ = tuba_settings;
		_tmp4_ = tuba_settings_get_favorite_tags_ids (_tmp3_, &_tmp5_);
		_tmp4__length1 = _tmp5_;
		_tmp6_ = _tmp4_;
		_tmp6__length1 = _tmp4__length1;
		_tmp0_ = _tmp6__length1 < TUBA_VIEWS_SIDEBAR_MAX_SIDEBAR_TAGS;
	}
	gtk_widget_set_sensitive ((GtkWidget*) self, _tmp0_);
}

static void
tuba_views_hashtags_favorite_tag_favorite_button_update_fav_status (TubaViewsHashtagsFavoriteTagFavoriteButton* self,
                                                                    const gchar* changed_tag)
{
	gboolean _tmp0_ = FALSE;
	gboolean in_list = FALSE;
	gchar* down_name = NULL;
	const gchar* _tmp6_;
	gchar* _tmp7_;
	TubaSettings* _tmp8_;
	gchar** _tmp9_;
	gint _tmp9__length1;
	gint _tmp10_ = 0;
	gchar** _tmp11_;
	gint _tmp11__length1;
	g_return_if_fail (self != NULL);
	if (changed_tag != NULL) {
		gchar* _tmp1_;
		gchar* _tmp2_;
		const gchar* _tmp3_;
		gchar* _tmp4_;
		gchar* _tmp5_;
		_tmp1_ = g_utf8_strdown (changed_tag, (gssize) -1);
		_tmp2_ = _tmp1_;
		_tmp3_ = self->priv->_tag;
		_tmp4_ = g_utf8_strdown (_tmp3_, (gssize) -1);
		_tmp5_ = _tmp4_;
		_tmp0_ = g_strcmp0 (_tmp2_, _tmp5_) != 0;
		_g_free0 (_tmp5_);
		_g_free0 (_tmp2_);
	} else {
		_tmp0_ = FALSE;
	}
	if (_tmp0_) {
		return;
	}
	in_list = FALSE;
	_tmp6_ = self->priv->_tag;
	_tmp7_ = g_utf8_strdown (_tmp6_, (gssize) -1);
	down_name = _tmp7_;
	_tmp8_ = tuba_settings;
	_tmp9_ = tuba_settings_get_favorite_tags_ids (_tmp8_, &_tmp10_);
	_tmp9__length1 = _tmp10_;
	_tmp11_ = _tmp9_;
	_tmp11__length1 = _tmp9__length1;
	{
		gchar** tag_name_collection = NULL;
		gint tag_name_collection_length1 = 0;
		gint _tag_name_collection_size_ = 0;
		gint tag_name_it = 0;
		tag_name_collection = _tmp11_;
		tag_name_collection_length1 = _tmp11__length1;
		for (tag_name_it = 0; tag_name_it < tag_name_collection_length1; tag_name_it = tag_name_it + 1) {
			gchar* _tmp12_;
			gchar* tag_name = NULL;
			_tmp12_ = g_strdup (tag_name_collection[tag_name_it]);
			tag_name = _tmp12_;
			{
				const gchar* _tmp13_;
				gchar* _tmp14_;
				gchar* _tmp15_;
				const gchar* _tmp16_;
				gboolean _tmp17_;
				_tmp13_ = tag_name;
				_tmp14_ = g_utf8_strdown (_tmp13_, (gssize) -1);
				_tmp15_ = _tmp14_;
				_tmp16_ = down_name;
				_tmp17_ = g_strcmp0 (_tmp15_, _tmp16_) == 0;
				_g_free0 (_tmp15_);
				if (_tmp17_) {
					in_list = TRUE;
					_g_free0 (tag_name);
					break;
				}
				_g_free0 (tag_name);
			}
		}
	}
	tuba_widgets_status_action_button_set_active ((TubaWidgetsStatusActionButton*) self, in_list);
	tuba_views_hashtags_favorite_tag_favorite_button_on_fav_tags_updated (self);
	_g_free0 (down_name);
}

static const gchar*
tuba_views_hashtags_favorite_tag_favorite_button_get_tag (TubaViewsHashtagsFavoriteTagFavoriteButton* self)
{
	const gchar* result;
	const gchar* _tmp0_;
	g_return_val_if_fail (self != NULL, NULL);
	_tmp0_ = self->priv->_tag;
	result = _tmp0_;
	return result;
}

static void
tuba_views_hashtags_favorite_tag_favorite_button_set_tag (TubaViewsHashtagsFavoriteTagFavoriteButton* self,
                                                          const gchar* value)
{
	gchar* _tmp0_;
	g_return_if_fail (self != NULL);
	_tmp0_ = g_strdup (value);
	_g_free0 (self->priv->_tag);
	self->priv->_tag = _tmp0_;
}

static gboolean
tuba_views_hashtags_favorite_tag_favorite_button_get_force_recheck (TubaViewsHashtagsFavoriteTagFavoriteButton* self)
{
	gboolean result;
	g_return_val_if_fail (self != NULL, FALSE);
	result = self->priv->_force_recheck;
	return result;
}

static void
tuba_views_hashtags_favorite_tag_favorite_button_set_force_recheck (TubaViewsHashtagsFavoriteTagFavoriteButton* self,
                                                                    gboolean value)
{
	g_return_if_fail (self != NULL);
	self->priv->_force_recheck = value;
}

static void
tuba_views_hashtags_favorite_tag_favorite_button_class_init (TubaViewsHashtagsFavoriteTagFavoriteButtonClass * klass,
                                                             gpointer klass_data)
{
	tuba_views_hashtags_favorite_tag_favorite_button_parent_class = g_type_class_peek_parent (klass);
	g_type_class_adjust_private_offset (klass, &TubaViewsHashtagsFavoriteTagFavoriteButton_private_offset);
	G_OBJECT_CLASS (klass)->get_property = _vala_tuba_views_hashtags_favorite_tag_favorite_button_get_property;
	G_OBJECT_CLASS (klass)->set_property = _vala_tuba_views_hashtags_favorite_tag_favorite_button_set_property;
	G_OBJECT_CLASS (klass)->finalize = tuba_views_hashtags_favorite_tag_favorite_button_finalize;
}

static void
tuba_views_hashtags_favorite_tag_favorite_button_instance_init (TubaViewsHashtagsFavoriteTagFavoriteButton * self,
                                                                gpointer klass)
{
	self->priv = tuba_views_hashtags_favorite_tag_favorite_button_get_instance_private (self);
	self->priv->_force_recheck = FALSE;
}

static void
tuba_views_hashtags_favorite_tag_favorite_button_finalize (GObject * obj)
{
	TubaViewsHashtagsFavoriteTagFavoriteButton * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, TUBA_VIEWS_HASHTAGS_FAVORITE_TAG_TYPE_FAVORITE_BUTTON, TubaViewsHashtagsFavoriteTagFavoriteButton);
	_g_free0 (self->priv->_tag);
	G_OBJECT_CLASS (tuba_views_hashtags_favorite_tag_favorite_button_parent_class)->finalize (obj);
}

 G_GNUC_NO_INLINE static GType
tuba_views_hashtags_favorite_tag_favorite_button_get_type_once (void)
{
	static const GTypeInfo g_define_type_info = { sizeof (TubaViewsHashtagsFavoriteTagFavoriteButtonClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) tuba_views_hashtags_favorite_tag_favorite_button_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (TubaViewsHashtagsFavoriteTagFavoriteButton), 0, (GInstanceInitFunc) tuba_views_hashtags_favorite_tag_favorite_button_instance_init, NULL };
	GType tuba_views_hashtags_favorite_tag_favorite_button_type_id;
	tuba_views_hashtags_favorite_tag_favorite_button_type_id = g_type_register_static (TUBA_WIDGETS_TYPE_STATUS_ACTION_BUTTON, "TubaViewsHashtagsFavoriteTagFavoriteButton", &g_define_type_info, G_TYPE_FLAG_NONE);
	TubaViewsHashtagsFavoriteTagFavoriteButton_private_offset = g_type_add_instance_private (tuba_views_hashtags_favorite_tag_favorite_button_type_id, sizeof (TubaViewsHashtagsFavoriteTagFavoriteButtonPrivate));
	return tuba_views_hashtags_favorite_tag_favorite_button_type_id;
}

GType
tuba_views_hashtags_favorite_tag_favorite_button_get_type (void)
{
	static GType tuba_views_hashtags_favorite_tag_favorite_button_type_id__once = 0;
	if (g_once_init_enter_pointer (&tuba_views_hashtags_favorite_tag_favorite_button_type_id__once)) {
		GType tuba_views_hashtags_favorite_tag_favorite_button_type_id;
		tuba_views_hashtags_favorite_tag_favorite_button_type_id = tuba_views_hashtags_favorite_tag_favorite_button_get_type_once ();
		g_once_init_leave_pointer (&tuba_views_hashtags_favorite_tag_favorite_button_type_id__once, tuba_views_hashtags_favorite_tag_favorite_button_type_id);
	}
	return tuba_views_hashtags_favorite_tag_favorite_button_type_id__once;
}

static void
_vala_tuba_views_hashtags_favorite_tag_favorite_button_get_property (GObject * object,
                                                                     guint property_id,
                                                                     GValue * value,
                                                                     GParamSpec * pspec)
{
	TubaViewsHashtagsFavoriteTagFavoriteButton * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, TUBA_VIEWS_HASHTAGS_FAVORITE_TAG_TYPE_FAVORITE_BUTTON, TubaViewsHashtagsFavoriteTagFavoriteButton);
	switch (property_id) {
		default:
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
		break;
	}
}

static void
_vala_tuba_views_hashtags_favorite_tag_favorite_button_set_property (GObject * object,
                                                                     guint property_id,
                                                                     const GValue * value,
                                                                     GParamSpec * pspec)
{
	TubaViewsHashtagsFavoriteTagFavoriteButton * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, TUBA_VIEWS_HASHTAGS_FAVORITE_TAG_TYPE_FAVORITE_BUTTON, TubaViewsHashtagsFavoriteTagFavoriteButton);
	switch (property_id) {
		default:
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
		break;
	}
}

static void
tuba_views_hashtags_favorite_tag_class_init (TubaViewsHashtagsFavoriteTagClass * klass,
                                             gpointer klass_data)
{
	tuba_views_hashtags_favorite_tag_parent_class = g_type_class_peek_parent (klass);
	g_type_class_adjust_private_offset (klass, &TubaViewsHashtagsFavoriteTag_private_offset);
	((TubaAPITagClass *) klass)->on_activated = (void (*) (TubaAPITag*)) tuba_views_hashtags_favorite_tag_real_on_activated;
	G_OBJECT_CLASS (klass)->get_property = _vala_tuba_views_hashtags_favorite_tag_get_property;
	G_OBJECT_CLASS (klass)->set_property = _vala_tuba_views_hashtags_favorite_tag_set_property;
	G_OBJECT_CLASS (klass)->finalize = tuba_views_hashtags_favorite_tag_finalize;
	g_object_class_install_property (G_OBJECT_CLASS (klass), TUBA_VIEWS_HASHTAGS_FAVORITE_TAG_TUBA_HASHTAG_DATA_PROPERTY, tuba_views_hashtags_favorite_tag_properties[TUBA_VIEWS_HASHTAGS_FAVORITE_TAG_TUBA_HASHTAG_DATA_PROPERTY] = g_param_spec_object ("tuba-hashtag-data", "tuba-hashtag-data", "tuba-hashtag-data", TUBA_DIALOGS_HASHTAG_LIST_TYPE_DATA, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
}

static void
tuba_views_hashtags_favorite_tag_tuba_widgetizable_interface_init (TubaWidgetizableIface * iface,
                                                                   gpointer iface_data)
{
	tuba_views_hashtags_favorite_tag_tuba_widgetizable_parent_iface = g_type_interface_peek_parent (iface);
	iface->to_widget = (GtkWidget* (*) (TubaWidgetizable*)) tuba_views_hashtags_favorite_tag_real_to_widget;
}

static void
tuba_views_hashtags_favorite_tag_instance_init (TubaViewsHashtagsFavoriteTag * self,
                                                gpointer klass)
{
	self->priv = tuba_views_hashtags_favorite_tag_get_instance_private (self);
	self->priv->_tuba_hashtag_data = NULL;
}

static void
tuba_views_hashtags_favorite_tag_finalize (GObject * obj)
{
	TubaViewsHashtagsFavoriteTag * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, TUBA_VIEWS_HASHTAGS_TYPE_FAVORITE_TAG, TubaViewsHashtagsFavoriteTag);
	_g_object_unref0 (self->priv->_tuba_hashtag_data);
	G_OBJECT_CLASS (tuba_views_hashtags_favorite_tag_parent_class)->finalize (obj);
}

 G_GNUC_NO_INLINE static GType
tuba_views_hashtags_favorite_tag_get_type_once (void)
{
	static const GTypeInfo g_define_type_info = { sizeof (TubaViewsHashtagsFavoriteTagClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) tuba_views_hashtags_favorite_tag_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (TubaViewsHashtagsFavoriteTag), 0, (GInstanceInitFunc) tuba_views_hashtags_favorite_tag_instance_init, NULL };
	static const GInterfaceInfo tuba_widgetizable_info = { (GInterfaceInitFunc) tuba_views_hashtags_favorite_tag_tuba_widgetizable_interface_init, (GInterfaceFinalizeFunc) NULL, NULL};
	GType tuba_views_hashtags_favorite_tag_type_id;
	tuba_views_hashtags_favorite_tag_type_id = g_type_register_static (TUBA_API_TYPE_TAG, "TubaViewsHashtagsFavoriteTag", &g_define_type_info, G_TYPE_FLAG_NONE);
	g_type_add_interface_static (tuba_views_hashtags_favorite_tag_type_id, TUBA_TYPE_WIDGETIZABLE, &tuba_widgetizable_info);
	TubaViewsHashtagsFavoriteTag_private_offset = g_type_add_instance_private (tuba_views_hashtags_favorite_tag_type_id, sizeof (TubaViewsHashtagsFavoriteTagPrivate));
	return tuba_views_hashtags_favorite_tag_type_id;
}

GType
tuba_views_hashtags_favorite_tag_get_type (void)
{
	static GType tuba_views_hashtags_favorite_tag_type_id__once = 0;
	if (g_once_init_enter_pointer (&tuba_views_hashtags_favorite_tag_type_id__once)) {
		GType tuba_views_hashtags_favorite_tag_type_id;
		tuba_views_hashtags_favorite_tag_type_id = tuba_views_hashtags_favorite_tag_get_type_once ();
		g_once_init_leave_pointer (&tuba_views_hashtags_favorite_tag_type_id__once, tuba_views_hashtags_favorite_tag_type_id);
	}
	return tuba_views_hashtags_favorite_tag_type_id__once;
}

static void
_vala_tuba_views_hashtags_favorite_tag_get_property (GObject * object,
                                                     guint property_id,
                                                     GValue * value,
                                                     GParamSpec * pspec)
{
	TubaViewsHashtagsFavoriteTag * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, TUBA_VIEWS_HASHTAGS_TYPE_FAVORITE_TAG, TubaViewsHashtagsFavoriteTag);
	switch (property_id) {
		case TUBA_VIEWS_HASHTAGS_FAVORITE_TAG_TUBA_HASHTAG_DATA_PROPERTY:
		g_value_set_object (value, tuba_views_hashtags_favorite_tag_get_tuba_hashtag_data (self));
		break;
		default:
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
		break;
	}
}

static void
_vala_tuba_views_hashtags_favorite_tag_set_property (GObject * object,
                                                     guint property_id,
                                                     const GValue * value,
                                                     GParamSpec * pspec)
{
	TubaViewsHashtagsFavoriteTag * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, TUBA_VIEWS_HASHTAGS_TYPE_FAVORITE_TAG, TubaViewsHashtagsFavoriteTag);
	switch (property_id) {
		case TUBA_VIEWS_HASHTAGS_FAVORITE_TAG_TUBA_HASHTAG_DATA_PROPERTY:
		tuba_views_hashtags_favorite_tag_set_tuba_hashtag_data (self, g_value_get_object (value));
		break;
		default:
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
		break;
	}
}

static GObject *
tuba_views_hashtags_constructor (GType type,
                                 guint n_construct_properties,
                                 GObjectConstructParam * construct_properties)
{
	GObject * obj;
	GObjectClass * parent_class;
	TubaViewsHashtags * self;
	parent_class = G_OBJECT_CLASS (tuba_views_hashtags_parent_class);
	obj = parent_class->constructor (type, n_construct_properties, construct_properties);
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, TUBA_VIEWS_TYPE_HASHTAGS, TubaViewsHashtags);
	tuba_views_timeline_set_accepts ((TubaViewsTimeline*) self, TUBA_VIEWS_HASHTAGS_TYPE_FAVORITE_TAG);
	return obj;
}

static void
tuba_views_hashtags_class_init (TubaViewsHashtagsClass * klass,
                                gpointer klass_data)
{
	tuba_views_hashtags_parent_class = g_type_class_peek_parent (klass);
	((TubaViewsTimelineClass *) klass)->on_request_finish = (void (*) (TubaViewsTimeline*)) tuba_views_hashtags_real_on_request_finish;
	((TubaViewsBaseClass *) klass)->build_header = (void (*) (TubaViewsBase*)) tuba_views_hashtags_real_build_header;
	((TubaViewsTimelineClass *) klass)->on_refresh = (void (*) (TubaViewsTimeline*)) tuba_views_hashtags_real_on_refresh;
	G_OBJECT_CLASS (klass)->constructor = tuba_views_hashtags_constructor;
}

static void
tuba_views_hashtags_instance_init (TubaViewsHashtags * self,
                                   gpointer klass)
{
}

 G_GNUC_NO_INLINE static GType
tuba_views_hashtags_get_type_once (void)
{
	static const GTypeInfo g_define_type_info = { sizeof (TubaViewsHashtagsClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) tuba_views_hashtags_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (TubaViewsHashtags), 0, (GInstanceInitFunc) tuba_views_hashtags_instance_init, NULL };
	GType tuba_views_hashtags_type_id;
	tuba_views_hashtags_type_id = g_type_register_static (TUBA_VIEWS_TYPE_TIMELINE, "TubaViewsHashtags", &g_define_type_info, G_TYPE_FLAG_NONE);
	return tuba_views_hashtags_type_id;
}

GType
tuba_views_hashtags_get_type (void)
{
	static GType tuba_views_hashtags_type_id__once = 0;
	if (g_once_init_enter_pointer (&tuba_views_hashtags_type_id__once)) {
		GType tuba_views_hashtags_type_id;
		tuba_views_hashtags_type_id = tuba_views_hashtags_get_type_once ();
		g_once_init_leave_pointer (&tuba_views_hashtags_type_id__once, tuba_views_hashtags_type_id);
	}
	return tuba_views_hashtags_type_id__once;
}

static void
_vala_array_destroy (gpointer array,
                     gssize array_length,
                     GDestroyNotify destroy_func)
{
	if ((array != NULL) && (destroy_func != NULL)) {
		gssize i;
		for (i = 0; i < array_length; i = i + 1) {
			if (((gpointer*) array)[i] != NULL) {
				destroy_func (((gpointer*) array)[i]);
			}
		}
	}
}

static void
_vala_array_free (gpointer array,
                  gssize array_length,
                  GDestroyNotify destroy_func)
{
	_vala_array_destroy (array, array_length, destroy_func);
	g_free (array);
}

